@@ -10,10 +10,12 @@ __email__ = (
     "mikolaj.rybinski@id.ethz.ch, dev@davidgraber.ch, henrik.menne@eeh.ee.ethz.ch, "
     "chachereau@eeh.ee.ethz.ch, janssen@eeh.ee.ethz.ch, dtaylor@ethz.ch"
 )
-__version__ = "0.14.4"
+__version__ = "0.18.2"
 
-from . import comm  # noqa: F401
-from . import dev  # noqa: F401
+from . import (
+    comm,  # noqa: F401
+    dev,  # noqa: F401
+)
 from .configuration import ConfigurationMixin, configdataclass  # noqa: F401
 from .experiment_manager import (  # noqa: F401
     ExperimentError,
