@@ -15,15 +15,17 @@ for some minutes. Do not apply abrupt changes of pulse energy or repetition rate
 
 Manufacturer homepage:
 https://www.crylas.de/products/pulsed_laser.html
+
+TODO: Fix typing
 """
 
 import logging
 import math
 import re
 import time
+from collections.abc import Callable
 from datetime import datetime
 from threading import Event
-from typing import Callable, Optional, Union
 
 from aenum import Enum, IntEnum
 
@@ -48,15 +50,13 @@ class CryLasLaserSerialCommunicationConfig(SerialCommunicationConfig):
     baudrate: int = 19200
 
     #: CryLas laser does not use parity
-    parity: Union[str, SerialCommunicationParity] = SerialCommunicationParity.NONE
+    parity: str | SerialCommunicationParity = SerialCommunicationParity.NONE
 
     #: CryLas laser uses one stop bit
-    stopbits: Union[int, SerialCommunicationStopbits] = SerialCommunicationStopbits.ONE
+    stopbits: int | SerialCommunicationStopbits = SerialCommunicationStopbits.ONE
 
     #: One byte is eight bits long
-    bytesize: Union[int, SerialCommunicationBytesize] = (
-        SerialCommunicationBytesize.EIGHTBITS
-    )
+    bytesize: int | SerialCommunicationBytesize = SerialCommunicationBytesize.EIGHTBITS
 
     #: The terminator is LF
     terminator: bytes = b"\n"
@@ -96,7 +96,7 @@ class CryLasLaserSerialCommunication(SerialCommunication):
             logger.debug(f'Laser com: "{line.rstrip()}"')
             return line
 
-    def query(self, cmd: str, prefix: str, post_cmd: Optional[str] = None) -> str:
+    def query(self, cmd: str, prefix: str, post_cmd: str | None = None) -> str:
         """
         Send a command, then read the com until a line starting with prefix,
         or an empty line, is found. Returns the line in question.
@@ -107,7 +107,8 @@ class CryLasLaserSerialCommunication(SerialCommunication):
         :return: line in question as a string
         :raises SerialCommunicationIOError: when communication port is not opened
         """
-        # TODO: Make use of SyncCommunicationProtocol
+        # TODO: Make use of SyncCommunicationProtocol  # noqa: FIX002
+        # https://gitlab.com/ethz_hvl/hvl_ccb/-/issues/372
 
         with self.access_lock:
             # send the command
@@ -121,7 +122,7 @@ class CryLasLaserSerialCommunication(SerialCommunication):
                 self.write(post_cmd)
             return line
 
-    def query_all(self, cmd: str, prefix: str):
+    def query_all(self, cmd: str, prefix: str) -> list:
         """
         Send a command, then read the com until a line starting with prefix,
         or an empty line, is found. Returns a list of successive lines starting with
@@ -132,7 +133,8 @@ class CryLasLaserSerialCommunication(SerialCommunication):
         :return: line in question as a string
         :raises SerialCommunicationIOError: when communication port is not opened
         """
-        # TODO: Make use of SyncCommunicationProtocol
+        # TODO: Make use of SyncCommunicationProtocol  # noqa: FIX002
+        # https://gitlab.com/ethz_hvl/hvl_ccb/-/issues/372
 
         with self.access_lock:
             # send the command
@@ -171,7 +173,7 @@ class CryLasLaserConfig:
 
     # polling period (s) to check back on the laser status if not ready
     # it should be longer than the communication timeout
-    polling_period: Union[int, float] = 12
+    polling_period: int | float = 12
 
     # timeout (s) when polling the laser status, CryLasLaserError is raised on timeout
     polling_timeout: Number = 300
@@ -180,18 +182,21 @@ class CryLasLaserConfig:
     auto_laser_on: bool = True
 
     # status of the shutter to be set on start
-    init_shutter_status: Union[int, CryLasLaserShutterStatus] = (
+    init_shutter_status: int | CryLasLaserShutterStatus = (
         CryLasLaserShutterStatus.CLOSED
     )
 
-    def clean_values(self):
+    def clean_values(self) -> None:
         if self.calibration_factor <= 0:
-            raise ValueError("The calibration factor should be positive.")
+            msg = "The calibration factor should be positive."
+            raise ValueError(msg)
         if self.polling_period <= 0:
-            raise ValueError("The polling period should be positive.")
+            msg = "The polling period should be positive."
+            raise ValueError(msg)
         if self.polling_timeout <= 0:
-            raise ValueError("The polling timeout should be positive.")
-        self.force_value(
+            msg = "The polling timeout should be positive."
+            raise ValueError(msg)
+        self.force_value(  # type: ignore[attr-defined]
             "init_shutter_status", self.ShutterStatus(self.init_shutter_status)
         )
 
@@ -204,14 +209,14 @@ class CryLasLaserPoller(Poller):
     :raises SerialCommunicationIOError: when communication port is closed.
     """
 
-    def __init__(
+    def __init__(  # noqa: ANN204
         self,
         spoll_handler: Callable,
         check_handler: Callable,
         check_laser_status_handler: Callable,
         polling_delay_sec: Number = 0,
         polling_interval_sec: Number = 1,
-        polling_timeout_sec: Optional[Number] = None,
+        polling_timeout_sec: Number | None = None,
     ):
         """
         Initialize the polling helper.
@@ -230,7 +235,7 @@ class CryLasLaserPoller(Poller):
         self._check_laser_status_handler = check_laser_status_handler
 
     def _if_poll_again(
-        self, stop_event: Event, delay_sec: Number, stop_time: Optional[Number]
+        self, stop_event: Event, delay_sec: Number, stop_time: Number | None
     ) -> bool:
         """
         Check if to poll again.
@@ -245,7 +250,7 @@ class CryLasLaserPoller(Poller):
 
         return if_poll_again and not is_laser_ready
 
-    def _poll_until_stop_or_timeout(self, stop_event: Event) -> Optional[object]:
+    def _poll_until_stop_or_timeout(self, stop_event: Event) -> object | None:
         """
         Thread for polling until stopped, timed-out or the laser is ready.
 
@@ -257,9 +262,8 @@ class CryLasLaserPoller(Poller):
         if stop_event.wait(0):
             logger.info(f"[{datetime.now()}] Polling status: ... STOPPED")
             return last_result
-        else:
-            self._check_handler()
 
+        self._check_handler()
         return last_result
 
 
@@ -278,11 +282,11 @@ class CryLasLaser(SingleCommDevice):
         READY_ACTIVE = 2
 
         @property
-        def is_ready(self):
+        def is_ready(self) -> bool:
             return self is not CryLasLaser.LaserStatus.UNREADY_INACTIVE
 
         @property
-        def is_inactive(self):
+        def is_inactive(self) -> bool:
             return self is not CryLasLaser.LaserStatus.READY_ACTIVE
 
     # status of the shutter
@@ -310,7 +314,7 @@ class CryLasLaser(SingleCommDevice):
         ACTIVE = "STATUS: Laser active"
         INACTIVE = "STATUS: Laser inactive"
 
-    class RepetitionRates(IntEnum, init="value send_value"):  # type: ignore
+    class RepetitionRates(IntEnum, init="value send_value"):  # type: ignore[call-arg]
         """
         Repetition rates for the internal software trigger in Hz
         """
@@ -321,7 +325,7 @@ class CryLasLaser(SingleCommDevice):
         SOFTWARE_INTERNAL_TWENTY = 20, 2
         SOFTWARE_INTERNAL_SIXTY = 60, 3
 
-    def __init__(self, com, dev_config=None):
+    def __init__(self, com, dev_config=None):  # noqa: ANN204
         # Call superclass constructor
         super().__init__(com, dev_config)
 
@@ -341,7 +345,7 @@ class CryLasLaser(SingleCommDevice):
         self._status_poller = None
 
     @property
-    def target_pulse_energy(self):
+    def target_pulse_energy(self) -> int | None:
         return self._target_pulse_energy
 
     @staticmethod
@@ -359,7 +363,7 @@ class CryLasLaser(SingleCommDevice):
         :raises SerialCommunicationIOError: when communication port cannot be opened
         """
 
-        logger.info("Starting device " + str(self))
+        logger.info(f"Starting device {self}")
 
         # open the com
         super().start()
@@ -504,29 +508,29 @@ class CryLasLaser(SingleCommDevice):
             err_msg = "Command to query the laser status did not return an answer."
             logger.error(err_msg)
             raise CryLasLaserError(err_msg)
-        else:
-            # at least one line in answer_list
-            for line in answer_list:
-                answer = self.AnswersStatus(line)
-                if answer in (
-                    self.AnswersStatus.TEC1,
-                    self.AnswersStatus.TEC2,
-                    self.AnswersStatus.HEAD,
-                ):
-                    new_status = self.LaserStatus.UNREADY_INACTIVE
-                    info_msg = "The laser is not ready."
-                elif answer is self.AnswersStatus.READY:
-                    new_status = self.LaserStatus.READY_INACTIVE
-                    info_msg = "The laser is ready."
-                elif answer is self.AnswersStatus.ACTIVE:
-                    new_status = self.LaserStatus.READY_ACTIVE
-                    info_msg = "The laser is on."
-                else:
-                    err_msg = f'Unexpected "STATUS" query response {answer.value}.'
-                    logger.error(err_msg)
-                    raise CryLasLaserError(err_msg)
-            self.laser_status = new_status
-            logger.info(info_msg)
+
+        # at least one line in answer_list
+        for line in answer_list:
+            answer = self.AnswersStatus(line)
+            if answer in (
+                self.AnswersStatus.TEC1,
+                self.AnswersStatus.TEC2,
+                self.AnswersStatus.HEAD,
+            ):
+                new_status = self.LaserStatus.UNREADY_INACTIVE
+                info_msg = "The laser is not ready."
+            elif answer is self.AnswersStatus.READY:
+                new_status = self.LaserStatus.READY_INACTIVE
+                info_msg = "The laser is ready."
+            elif answer is self.AnswersStatus.ACTIVE:
+                new_status = self.LaserStatus.READY_ACTIVE
+                info_msg = "The laser is on."
+            else:
+                err_msg = f'Unexpected "STATUS" query response {answer.value}.'
+                logger.error(err_msg)
+                raise CryLasLaserError(err_msg)
+        self.laser_status = new_status
+        logger.info(info_msg)
 
     def update_shutter_status(self) -> None:
         """
@@ -543,14 +547,14 @@ class CryLasLaser(SingleCommDevice):
             err_msg = "Command to query the shutter status did not return an answer."
             logger.error(err_msg)
             raise CryLasLaserError(err_msg)
-        else:
-            answer = self.AnswersShutter(answer)
-            if answer is self.AnswersShutter.CLOSED:
-                logger.info("The laser shutter is currently CLOSED.")
-                self.shutter_status = self.ShutterStatus.CLOSED
-            elif answer is self.AnswersShutter.OPENED:
-                logger.info("The laser shutter is currently OPENED.")
-                self.shutter_status = self.ShutterStatus.OPENED
+
+        answer = self.AnswersShutter(answer)
+        if answer is self.AnswersShutter.CLOSED:
+            logger.info("The laser shutter is currently CLOSED.")
+            self.shutter_status = self.ShutterStatus.CLOSED
+        elif answer is self.AnswersShutter.OPENED:
+            logger.info("The laser shutter is currently OPENED.")
+            self.shutter_status = self.ShutterStatus.OPENED
 
     def update_repetition_rate(self) -> None:
         """
@@ -567,7 +571,7 @@ class CryLasLaser(SingleCommDevice):
             err_msg = "Querying the repetition rate did not return an answer."
             logger.error(err_msg)
             raise CryLasLaserError(err_msg)
-        elif answer == "Impuls=disabled, extern Trigger":
+        if answer == "Impuls=disabled, extern Trigger":
             logger.info(
                 "The laser is using a hardware trigger (may be internal or external)."
             )
@@ -604,12 +608,12 @@ class CryLasLaser(SingleCommDevice):
             )
             logger.error(err_msg)
             raise CryLasLaserError(err_msg)
-        else:
-            current_value = int(answer.split("=")[1])
-            current_energy = int(current_value * self.config.calibration_factor / 1000)
-            # update the pulse energy attribute
-            self._target_pulse_energy = current_energy
-            logger.info(f"The target pulse energy is {current_energy} uJ.")
+
+        current_value = int(answer.split("=")[1])
+        current_energy = int(current_value * self.config.calibration_factor / 1000)
+        # update the pulse energy attribute
+        self._target_pulse_energy = current_energy
+        logger.info(f"The target pulse energy is {current_energy} uJ.")
 
     def laser_on(self) -> None:
         """
@@ -621,24 +625,25 @@ class CryLasLaser(SingleCommDevice):
         """
 
         if not self.laser_status.is_ready:
-            raise CryLasLaserNotReadyError("Laser not ready, cannot be turned on yet.")
-        else:
-            # send the command
-            answer = self.com.query("LASER ON", "STATUS: Laser")
-            # analyse the answer
-            if not answer or self.AnswersStatus(answer) != self.AnswersStatus.ACTIVE:
-                if not self.laser_status.is_inactive:
-                    logger.info("Laser is already on.")
-                else:
-                    err_msg = (
-                        "Command to turn on the laser "
-                        f"{'failed' if answer else 'did not return an answer'}."
-                    )
-                    logger.error(err_msg)
-                    raise CryLasLaserError(err_msg)
+            msg = "Laser not ready, cannot be turned on yet."
+            raise CryLasLaserNotReadyError(msg)
+
+        # send the command
+        answer = self.com.query("LASER ON", "STATUS: Laser")
+        # analyse the answer
+        if not answer or self.AnswersStatus(answer) != self.AnswersStatus.ACTIVE:
+            if not self.laser_status.is_inactive:
+                logger.info("Laser is already on.")
             else:
-                self.laser_status = self.LaserStatus.READY_ACTIVE
-                logger.info("Laser is turned on.")
+                err_msg = (
+                    "Command to turn on the laser "
+                    f"{'failed' if answer else 'did not return an answer'}."
+                )
+                logger.error(err_msg)
+                raise CryLasLaserError(err_msg)
+        else:
+            self.laser_status = self.LaserStatus.READY_ACTIVE
+            logger.info("Laser is turned on.")
 
     def laser_off(self) -> None:
         """
@@ -685,9 +690,9 @@ class CryLasLaser(SingleCommDevice):
             )
             logger.error(err_msg)
             raise CryLasLaserError(err_msg)
-        else:
-            logger.info("Opening laser shutter succeeded.")
-            self.shutter_status = self.ShutterStatus.OPENED
+
+        logger.info("Opening laser shutter succeeded.")
+        self.shutter_status = self.ShutterStatus.OPENED
 
     def close_shutter(self) -> None:
         """
@@ -709,9 +714,9 @@ class CryLasLaser(SingleCommDevice):
             )
             logger.error(err_msg)
             raise CryLasLaserError(err_msg)
-        else:
-            logger.info("Closing laser shutter succeeded.")
-            self.shutter_status = self.ShutterStatus.CLOSED
+
+        logger.info("Closing laser shutter succeeded.")
+        self.shutter_status = self.ShutterStatus.CLOSED
 
     def set_init_shutter_status(self) -> None:
         """
@@ -743,17 +748,17 @@ class CryLasLaser(SingleCommDevice):
             err_msg = "Command to find laser energy and rate did not return an answer."
             logger.error(err_msg)
             raise CryLasLaserError(err_msg)
-        else:
-            # the answer should look like 'IST: LDTemp=x, NLOTemp=x, CaseTemp=x,
-            # PD=x, D_I= x, freq=x, LDE=x, RegOFF=x' where x are integers
-            # find the values of interest
-            values = re.findall(r"\d+", answer)
-            energy = int(int(values[3]) * self.config.calibration_factor / 1000)
-            rate = int(values[5])
-            logger.info(f"Laser energy: {energy} uJ, repetition rate: {rate} Hz.")
-            return energy, rate
 
-    def set_repetition_rate(self, rate: Union[int, RepetitionRates]) -> None:
+        # the answer should look like 'IST: LDTemp=x, NLOTemp=x, CaseTemp=x,
+        # PD=x, D_I= x, freq=x, LDE=x, RegOFF=x' where x are integers
+        # find the values of interest
+        values = re.findall(r"\d+", answer)
+        energy = int(int(values[3]) * self.config.calibration_factor / 1000)
+        rate = int(values[5])
+        logger.info(f"Laser energy: {energy} uJ, repetition rate: {rate} Hz.")
+        return energy, rate
+
+    def set_repetition_rate(self, rate: int | RepetitionRates) -> None:
         """
         Sets the repetition rate of the internal software trigger.
 
@@ -768,8 +773,8 @@ class CryLasLaser(SingleCommDevice):
             try:
                 rate = self.RepetitionRates(rate)
             except ValueError as e:
-                logger.error(str(e), exc_info=e)
-                raise e
+                logger.exception("Error of Crylas: Wrong RepetitionRate", exc_info=e)
+                raise
         # send the corresponding value to the controller
         answer = self.com.query(f"BOO IP{rate.send_value}", "Impuls=")
         # check the success of the command
@@ -782,8 +787,8 @@ class CryLasLaser(SingleCommDevice):
                 )
                 logger.error(err_msg)
                 raise CryLasLaserError(err_msg)
-            else:
-                logger.info(f"Laser internal software trigger set to {rate.value} Hz")
+
+            logger.info(f"Laser internal software trigger set to {rate.value} Hz")
         else:
             # For the internal hardware trigger rate, there is no way to check success
             logger.info("Using laser internal hardware trigger.")
@@ -809,22 +814,22 @@ class CryLasLaser(SingleCommDevice):
             err_msg = "Command to set the pulse energy did not return an answer."
             logger.error(err_msg)
             raise CryLasLaserError(err_msg)
-        else:
-            current_value = int(answer.split("=")[1])
-            current_energy = int(current_value * self.config.calibration_factor / 1000)
-            # update the pulse energy attribute
-            self._target_pulse_energy = current_energy
-            if current_value != command_value:
-                message = (
-                    "Command to set the pulse energy failed. "
-                    f"The pulse energy is currently set to {current_energy} "
-                    "micro joule. Setting a different value is only possible "
-                    "when using an external hardware trigger."
-                )
-                logger.error(message)
-                raise CryLasLaserError(message)
-            else:
-                logger.info(f"Successfully set pulse energy to {energy}")
+
+        current_value = int(answer.split("=")[1])
+        current_energy = int(current_value * self.config.calibration_factor / 1000)
+        # update the pulse energy attribute
+        self._target_pulse_energy = current_energy
+        if current_value != command_value:
+            message = (
+                "Command to set the pulse energy failed. "
+                f"The pulse energy is currently set to {current_energy} "
+                "micro joule. Setting a different value is only possible "
+                "when using an external hardware trigger."
+            )
+            logger.error(message)
+            raise CryLasLaserError(message)
+
+        logger.info(f"Successfully set pulse energy to {energy}")
 
 
 class CryLasLaserError(DeviceError):
@@ -832,16 +837,12 @@ class CryLasLaserError(DeviceError):
     General error with the CryLas Laser.
     """
 
-    pass
-
 
 class CryLasLaserNotReadyError(CryLasLaserError):
     """
     Error when trying to turn on the CryLas Laser before it is ready.
     """
 
-    pass
-
 
 @configdataclass
 class CryLasAttenuatorSerialCommunicationConfig(SerialCommunicationConfig):
@@ -849,15 +850,13 @@ class CryLasAttenuatorSerialCommunicationConfig(SerialCommunicationConfig):
     baudrate: int = 9600
 
     #: CryLas attenuator does not use parity
-    parity: Union[str, SerialCommunicationParity] = SerialCommunicationParity.NONE
+    parity: str | SerialCommunicationParity = SerialCommunicationParity.NONE
 
     #: CryLas attenuator uses one stop bit
-    stopbits: Union[int, SerialCommunicationStopbits] = SerialCommunicationStopbits.ONE
+    stopbits: int | SerialCommunicationStopbits = SerialCommunicationStopbits.ONE
 
     #: One byte is eight bits long
-    bytesize: Union[int, SerialCommunicationBytesize] = (
-        SerialCommunicationBytesize.EIGHTBITS
-    )
+    bytesize: int | SerialCommunicationBytesize = SerialCommunicationBytesize.EIGHTBITS
 
     #: No terminator
     terminator: bytes = b""
@@ -888,11 +887,13 @@ class CryLasAttenuatorConfig:
     init_attenuation: Number = 0
     response_sleep_time: Number = 1
 
-    def clean_values(self):
+    def clean_values(self) -> None:
         if not 0 <= self.init_attenuation <= 100:
-            raise ValueError("Attenuation should be between 0 and 100 included.")
+            msg = "Attenuation should be between 0 and 100 included."
+            raise ValueError(msg)
         if self.response_sleep_time <= 0:
-            raise ValueError("Response sleep time should be positive.")
+            msg = "Response sleep time should be positive."
+            raise ValueError(msg)
 
 
 class CryLasAttenuator(SingleCommDevice):
@@ -900,7 +901,7 @@ class CryLasAttenuator(SingleCommDevice):
     Device class for the CryLas laser attenuator.
     """
 
-    def __init__(self, com, dev_config=None):
+    def __init__(self, com, dev_config=None):  # noqa: ANN204
         # Call superclass constructor
         super().__init__(com, dev_config)
 
@@ -933,7 +934,7 @@ class CryLasAttenuator(SingleCommDevice):
         super().start()
         self.set_init_attenuation()
 
-    def set_init_attenuation(self):
+    def set_init_attenuation(self) -> None:
         """
         Sets the attenuation to its configured initial/default value
 
@@ -952,34 +953,33 @@ class CryLasAttenuator(SingleCommDevice):
         """
 
         if not 0 <= percent <= 100:
-            raise ValueError("Attenuation should be between 0 and 100 included.")
-        else:
-            pulse = int(math.asin((50 - percent) * 0.02) * 536.5 + 6000)
-            prepulse = pulse - 400
-            # prepare the values to send with the motor protocol
-            lsb = prepulse % 128
-            msb = math.floor(prepulse / 128)
-            # send the values
-            self.com.write_bytes(bytes([132, 0, lsb, msb]))
-            time.sleep(self.config.response_sleep_time)
-            lsb = pulse % 128
-            msb = math.floor(pulse / 128)
-            self.com.write_bytes(bytes([132, 0, lsb, msb]))
-            time.sleep(self.config.response_sleep_time / 10)
-            self.com.write_bytes(bytes([161]))
-            time.sleep(self.config.response_sleep_time / 10)
-            b1 = self.com.read_single_bytes()
-            b2 = self.com.read_single_bytes()
-            logger.debug(f"b1 = {b1}, b2 = {b2}")
-            if b1 != b"\x00" or b2 != b"\x00":
-                err_msg = f"Setting laser attenuation to {percent} percents failed."
-                logger.error(err_msg)
-                raise CryLasAttenuatorError(err_msg)
-            else:
-                logger.info(
-                    f"Successfully set laser attenuation to {percent} Cpercents."
-                )
-                self._attenuation = percent
+            msg = "Attenuation should be between 0 and 100 included."
+            raise ValueError(msg)
+
+        pulse = int(math.asin((50 - percent) * 0.02) * 536.5 + 6000)
+        prepulse = pulse - 400
+        # prepare the values to send with the motor protocol
+        lsb = prepulse % 128
+        msb = math.floor(prepulse / 128)
+        # send the values
+        self.com.write_bytes(bytes([132, 0, lsb, msb]))
+        time.sleep(self.config.response_sleep_time)
+        lsb = pulse % 128
+        msb = math.floor(pulse / 128)
+        self.com.write_bytes(bytes([132, 0, lsb, msb]))
+        time.sleep(self.config.response_sleep_time / 10)
+        self.com.write_bytes(bytes([161]))
+        time.sleep(self.config.response_sleep_time / 10)
+        b1 = self.com.read_single_bytes()
+        b2 = self.com.read_single_bytes()
+        logger.debug(f"b1 = {b1}, b2 = {b2}")
+        if b1 != b"\x00" or b2 != b"\x00":
+            err_msg = f"Setting laser attenuation to {percent} percents failed."
+            logger.error(err_msg)
+            raise CryLasAttenuatorError(err_msg)
+
+        logger.info(f"Successfully set laser attenuation to {percent} Cpercents.")
+        self._attenuation = percent
 
     def set_transmission(self, percent: Number) -> None:
         """
@@ -997,5 +997,3 @@ class CryLasAttenuatorError(DeviceError):
     """
     General error with the CryLas Attenuator.
     """
-
-    pass
