@@ -3,6 +3,7 @@
 """
 EarthingStick of the different "Cubes".
 """
+
 import logging
 
 from .constants import SafetyStatus
@@ -23,13 +24,13 @@ class _EarthingStick(_Switch):
     """
 
     _STICKS: tuple = (1, 2, 3, 4, 5, 6)
-    _CLS_ERROR = CubeEarthingStickOperationError
-    _SWITCHABLE_AT_STATES = (
+    _ERROR_CLS = CubeEarthingStickOperationError
+    _SWITCHABLE_AT_STATES = (  # type: ignore[assignment]
         SafetyStatus.RED_READY,
         SafetyStatus.RED_OPERATE,
-    )  # type:ignore
+    )
 
-    def __init__(self, handle, number: int):
+    def __init__(self, handle, number: int) -> None:
         super().__init__(handle, device_name=f"Earthing Stick {number}")
 
         self._CMD_STATUS: str = (
