@@ -10,7 +10,8 @@ This can be NI-Visa oder pyvisa-py (up to now, all the testing was done with NI-
 import dataclasses
 import logging
 import time
-from typing import ClassVar, Iterable, Optional, Union
+from collections.abc import Iterable
+from typing import ClassVar
 
 from hvl_ccb.comm.visa import VisaCommunication, VisaCommunicationConfig
 from hvl_ccb.configuration import configdataclass
@@ -26,8 +27,6 @@ class PSI9000Error(DeviceError):
     Base error class regarding problems with the PSI 9000 supply.
     """
 
-    pass
-
 
 @configdataclass
 class PSI9000VisaCommunicationConfig(VisaCommunicationConfig):
@@ -36,9 +35,9 @@ class PSI9000VisaCommunicationConfig(VisaCommunicationConfig):
     power supply.
     """
 
-    interface_type: Union[
-        str, VisaCommunicationConfig.InterfaceType
-    ] = VisaCommunicationConfig.InterfaceType.TCPIP_SOCKET  # type: ignore
+    interface_type: str | VisaCommunicationConfig.InterfaceType = (
+        VisaCommunicationConfig.InterfaceType.TCPIP_SOCKET  # type: ignore[assignment]
+    )
 
 
 class PSI9000VisaCommunication(VisaCommunication):
@@ -94,9 +93,8 @@ class PSI9000Config(VisaDeviceConfig):
         super().clean_values()
         # check that power_limit is in range
         if self.power_limit > self._POWER_GRID_LIMIT or self.power_limit < 0:
-            raise ValueError(
-                f"Power limit out of range. Must be in 0..{self._POWER_GRID_LIMIT}"
-            )
+            msg = f"Power limit out of range. Must be in 0..{self._POWER_GRID_LIMIT}"
+            raise ValueError(msg)
 
         # check that lower voltage limits are in range
         if (
@@ -104,7 +102,8 @@ class PSI9000Config(VisaDeviceConfig):
             or self.voltage_lower_limit > self.voltage_upper_limit
             or self.voltage_lower_limit > self._VOLTAGE_UPPER_LIMIT
         ):
-            raise ValueError("Lower voltage limit out of range.")
+            msg = "Lower voltage limit out of range."
+            raise ValueError(msg)
 
         # check that upper voltage limits are in range
         if (
@@ -112,7 +111,8 @@ class PSI9000Config(VisaDeviceConfig):
             or self.voltage_upper_limit < self.voltage_lower_limit
             or self.voltage_upper_limit > self._VOLTAGE_UPPER_LIMIT
         ):
-            raise ValueError("Upper voltage limit out of range.")
+            msg = "Upper voltage limit out of range."
+            raise ValueError(msg)
 
         # check that lower current limits are in range
         if (
@@ -120,7 +120,8 @@ class PSI9000Config(VisaDeviceConfig):
             or self.current_lower_limit > self.current_upper_limit
             or self.current_lower_limit > self._CURRENT_UPPER_LIMIT
         ):
-            raise ValueError("Lower current limit out of range.")
+            msg = "Lower current limit out of range."
+            raise ValueError(msg)
 
         # check that upper current limits are in range
         if (
@@ -128,19 +129,19 @@ class PSI9000Config(VisaDeviceConfig):
             or self.current_upper_limit < self.current_lower_limit
             or self.current_upper_limit > self._CURRENT_UPPER_LIMIT
         ):
-            raise ValueError("Upper current limit out of range.")
+            msg = "Upper current limit out of range."
+            raise ValueError(msg)
         if self.wait_sec_system_lock <= 0:
-            raise ValueError(
-                "Wait time for system lock must be a positive value (in seconds)."
-            )
+            msg = "Wait time for system lock must be a positive value (in seconds)."
+            raise ValueError(msg)
         if self.wait_sec_settings_effect <= 0:
-            raise ValueError(
-                "Wait time for settings effect must be a positive value (in seconds)."
-            )
+            msg = "Wait time for settings effect must be a positive value (in seconds)."
+            raise ValueError(msg)
         if self.wait_sec_initialisation <= 0:
-            raise ValueError(
+            msg = (
                 "Wait time after initialisation must be a positive value (in seconds)."
             )
+            raise ValueError(msg)
 
 
 class PSI9000(VisaDevice):
@@ -159,9 +160,9 @@ class PSI9000(VisaDevice):
 
     def __init__(
         self,
-        com: Union[PSI9000VisaCommunication, PSI9000VisaCommunicationConfig, dict],
-        dev_config: Union[PSI9000Config, dict, None] = None,
-    ):
+        com: PSI9000VisaCommunication | PSI9000VisaCommunicationConfig | dict,
+        dev_config: PSI9000Config | dict | None = None,
+    ) -> None:
         super().__init__(com, dev_config)
 
     @staticmethod
@@ -173,7 +174,7 @@ class PSI9000(VisaDevice):
         Start this device.
         """
 
-        logger.info("Starting device " + str(self))
+        logger.info(f"Starting device {self}")
         super().start()
 
     def stop(self) -> None:
@@ -224,7 +225,8 @@ class PSI9000(VisaDevice):
 
             if not new_system_lock:
                 # locking was unsuccessful
-                raise PSI9000Error("Locking system unsuccessful.")
+                msg = "Locking system unsuccessful."
+                raise PSI9000Error(msg)
 
             logger.info("Power supply is now locked and ready for access.")
             return
@@ -250,7 +252,8 @@ class PSI9000(VisaDevice):
 
             if new_system_lock:
                 # locking was unsuccessful
-                raise PSI9000Error("Unlocking system was unsuccessful.")
+                msg = "Unlocking system was unsuccessful."
+                raise PSI9000Error(msg)
 
             logger.info("Power supply is now unlocked and ready for shutdown.")
             return
@@ -266,12 +269,11 @@ class PSI9000(VisaDevice):
         lock_string = self.com.query("SYSTem:LOCK:OWNer?")
         if lock_string == "REMOTE":
             return True
-        elif lock_string == "NONE" or lock_string == "LOCAL":
+        if lock_string == "NONE" or lock_string == "LOCAL":
             return False
-        else:
-            raise PSI9000Error(
-                f"Illegal answer to SYSTem:LOCK:OWNer? received: {lock_string}"
-            )
+
+        msg = f"Illegal answer to SYSTem:LOCK:OWNer? received: {lock_string}"
+        raise PSI9000Error(msg)
 
     def set_output(self, target_onstate: bool) -> None:
         """
@@ -291,13 +293,15 @@ class PSI9000(VisaDevice):
         if target_onstate and output_state:
             logger.info("Output successfully switched on.")
         elif target_onstate and not output_state:
-            logger.error("Output was not switched on.")
-            raise PSI9000Error("Output was not switched on.")
+            msg = "Output was not switched on."
+            logger.error(msg)
+            raise PSI9000Error(msg)
         elif not target_onstate and not output_state:
             logger.info("Output successfully switched off.")
         elif not target_onstate and output_state:
-            logger.error("Output was not switched off.")
-            raise PSI9000Error("Output was not switched off.")
+            msg = "Output was not switched off."
+            logger.error(msg)
+            raise PSI9000Error(msg)
 
     def get_output(self) -> bool:
         """
@@ -310,10 +314,11 @@ class PSI9000(VisaDevice):
         on_off_string = self.com.query("OUTPut?")
         if on_off_string == "ON":
             return True
-        elif on_off_string == "OFF":
+        if on_off_string == "OFF":
             return False
-        else:
-            raise PSI9000Error(f"Query of OUTPut? is not ON or OFF: {on_off_string}")
+
+        msg = f"Query of OUTPut? is not ON or OFF: {on_off_string}"
+        raise PSI9000Error(msg)
 
     def measure_voltage_current(self) -> tuple[float, float]:
         """
@@ -322,8 +327,12 @@ class PSI9000(VisaDevice):
         :return: Umeas in V, Imeas in A
         """
 
-        list_ret = self.com.query("MEASure:VOLTage?", "MEASure:CURRent?")
-        assert len(list_ret) == 2
+        list_ret = self.com.query_multiple("MEASure:VOLTage?", "MEASure:CURRent?")
+        if len(list_ret) != 2:
+            err_msg = f"Expected two values from query, but recieved {len(list_ret)}"
+            logger.error(err_msg)
+            raise PSI9000Error(err_msg)
+
         ret = self._remove_units(list_ret)
         return ret[0], ret[1]
 
@@ -341,7 +350,9 @@ class PSI9000(VisaDevice):
         :raises PSI9000Error: if the desired setpoint is out of limits
         """
 
-        self.com.write(f"SOURce:VOLTage {volt:f}", f"SOURce:CURRent {current:f}")
+        self.com.write_multiple(
+            f"SOURce:VOLTage {volt:f}", f"SOURce:CURRent {current:f}"
+        )
 
         read_voltage, read_current = self.get_voltage_current_setpoint()
 
@@ -353,7 +364,7 @@ class PSI9000(VisaDevice):
 
         else:
             v_lower, i_lower = self.get_ui_lower_limits()
-            v_upper, i_upper, p_upper = self.get_uip_upper_limits()
+            v_upper, i_upper, _p_upper = self.get_uip_upper_limits()
 
             err_msg = (
                 f"Setting U = {volt:f} V and I = {current:f} A was not successful: "
@@ -371,16 +382,20 @@ class PSI9000(VisaDevice):
         :return: Uset in V, Iset in A
         """
 
-        list_ret = self.com.query("SOURce:VOLTage?", "SOURce:CURRent?")
-        assert len(list_ret) == 2
+        list_ret = self.com.query_multiple("SOURce:VOLTage?", "SOURce:CURRent?")
+        if len(list_ret) != 2:
+            err_msg = f"Expected two values from query, but recieved {len(list_ret)}"
+            logger.error(err_msg)
+            raise PSI9000Error(err_msg)
+
         ret = self._remove_units(list_ret)
         return ret[0], ret[1]
 
     def set_upper_limits(
         self,
-        voltage_limit: Optional[float] = None,
-        current_limit: Optional[float] = None,
-        power_limit: Optional[float] = None,
+        voltage_limit: float | None = None,
+        current_limit: float | None = None,
+        power_limit: float | None = None,
     ) -> None:
         """
         Set the upper limits for voltage, current and power.
@@ -420,7 +435,7 @@ class PSI9000(VisaDevice):
             power_limit=power_limit,
         )
 
-        self.com.write(
+        self.com.write_multiple(
             f"SOURce:VOLTage:LIMit:HIGH {voltage_limit}",
             f"SOURce:CURRent:LIMit:HIGH {current_limit}",
             f"SOURce:POWer:LIMit:HIGH {power_limit}",
@@ -442,12 +457,13 @@ class PSI9000(VisaDevice):
             )
 
         else:
-            raise PSI9000Error("Setting upper limits was not successful.")
+            msg = "Setting upper limits was not successful."
+            raise PSI9000Error(msg)
 
     def set_lower_limits(
         self,
-        voltage_limit: Optional[float] = None,
-        current_limit: Optional[float] = None,
+        voltage_limit: float | None = None,
+        current_limit: float | None = None,
     ) -> None:
         """
         Set the lower limits for voltage and current.
@@ -482,7 +498,7 @@ class PSI9000(VisaDevice):
             current_lower_limit=current_limit,
         )
 
-        self.com.write(
+        self.com.write_multiple(
             f"SOURce:VOLTage:LIMit:LOW {voltage_limit}",
             f"SOURce:CURRent:LIMit:LOW {current_limit}",
         )
@@ -496,7 +512,8 @@ class PSI9000(VisaDevice):
             )
 
         else:
-            raise PSI9000Error("Setting lower limits was unsuccessful.")
+            msg = "Setting lower limits was unsuccessful."
+            raise PSI9000Error(msg)
 
     def get_ui_lower_limits(self) -> tuple[float, float]:
         """
@@ -505,10 +522,14 @@ class PSI9000(VisaDevice):
         :return: Umin in V, Imin in A
         """
 
-        list_ret = self.com.query(
+        list_ret = self.com.query_multiple(
             "SOURce:VOLTage:LIMit:LOW?", "SOURce:CURRent:LIMit:LOW?"
         )
-        assert len(list_ret) == 2
+        if len(list_ret) != 2:
+            err_msg = f"Expected two values from query, but recieved {len(list_ret)}"
+            logger.error(err_msg)
+            raise PSI9000Error(err_msg)
+
         ret = self._remove_units(list_ret)
         return ret[0], ret[1]
 
@@ -519,12 +540,16 @@ class PSI9000(VisaDevice):
         :return: Umax in V, Imax in A, Pmax in W
         """
 
-        list_ret = self.com.query(
+        list_ret = self.com.query_multiple(
             "SOURce:VOLTage:LIMit:HIGH?",
             "SOURce:CURRent:LIMit:HIGH?",
             "SOURce:POWer:LIMit:HIGH?",
         )
-        assert len(list_ret) == 3
+        if len(list_ret) != 3:
+            err_msg = f"Expected three values from query, but recieved {len(list_ret)}"
+            logger.error(err_msg)
+            raise PSI9000Error(err_msg)
+
         ret = self._remove_units(list_ret)
         return ret[0], ret[1], ret[2]
 
@@ -537,13 +562,15 @@ class PSI9000(VisaDevice):
 
         # verify that MS is enabled
         if self.com.query("SYSTem:MS:ENABle?") != "ON":
-            logger.error("Master-slave-mode not enabled.")
-            raise PSI9000Error("Master-slave-mode not enabled.")
+            msg = "Master-slave-mode not enabled."
+            logger.error(msg)
+            raise PSI9000Error(msg)
 
         # verify that this device ist MASTER
         if self.com.query("SYSTem:MS:LINK?") != "MASTER":
-            logger.error("Device is not Master.")
-            raise PSI9000Error("Device is not Master.")
+            msg = "Device is not Master."
+            logger.error(msg)
+            raise PSI9000Error(msg)
 
         # begin initialization
         self.com.write("SYSTem:MS:INITialisation")
@@ -551,12 +578,15 @@ class PSI9000(VisaDevice):
 
         # check for correct init
         if self.com.query("SYSTem:MS:CONDition?") != "INIT":
-            logger.error("Master-slave initialisation failed.")
-            raise PSI9000Error("Master-slave initialisation failed.")
+            msg = "Master-slave initialisation failed."
+            logger.error(msg)
+            raise PSI9000Error(msg)
 
         # read resulting master-slave nominal voltage and current
         ms_voltage, ms_current = self._remove_units(
-            self.com.query("SYSTem:MS:NOMinal:VOLTage?", "SYSTem:MS:NOMinal:CURRent?")
+            self.com.query_multiple(
+                "SYSTem:MS:NOMinal:VOLTage?", "SYSTem:MS:NOMinal:CURRent?"
+            )
         )
 
         # check for correct total voltage and current
