@@ -21,23 +21,8 @@ https://www.fug-elektronik.de/wp-content/uploads/download/de/SOFTWARE/Probus_V.z
 
 The provided classes support the basic and some advanced commands.
 The commands for calibrating the power supplies are not implemented, as they are only
-for very special porpoises and
-should not used by "normal" customers.
+for very special porpoises and should not used by "normal" customers.
 """
 
-from .fug import (  # noqa: F401
-    FuG,
-    FuGConfig,
-    FuGDigitalVal,
-    FuGError,
-    FuGErrorcodes,
-    FuGMonitorModes,
-    FuGPolarities,
-    FuGProbusIV,
-    FuGProbusIVCommands,
-    FuGRampModes,
-    FuGReadbackChannels,
-    FuGSerialCommunication,
-    FuGSerialCommunicationConfig,
-    FuGTerminators,
-)
+from .errors import FuGError  # noqa: F401
+from .fug import FuG  # noqa: F401
