@@ -14,10 +14,11 @@ or PNCcap.
 Manufacturer homepage:
 https://www.heinzinger.com/en/products/pnc-serie
 """
+
 import logging
 import re
 from time import sleep
-from typing import Optional, Union
+from typing import cast
 
 from hvl_ccb.configuration import configdataclass
 from hvl_ccb.dev.base import SingleCommDevice
@@ -42,7 +43,7 @@ class HeinzingerConfig:
 
     #: default number of recordings used in averaging the current
     #  or the voltage [1, 2, 4, 8, 16]
-    default_number_of_recordings: Union[int, RecordingsEnum] = 1
+    default_number_of_recordings: int | RecordingsEnum = 1
 
     #: number of decimals sent for setting the current limit or the voltage, between 1
     #  and 10
@@ -51,23 +52,23 @@ class HeinzingerConfig:
     #: Time to wait after subsequent commands during stop (in seconds)
     wait_sec_stop_commands: Number = 0.5
 
-    def clean_values(self):
+    def clean_values(self) -> None:
         if not isinstance(self.default_number_of_recordings, RecordingsEnum):
-            self.force_value(
+            self.force_value(  # type: ignore[attr-defined]
                 "default_number_of_recordings",
                 RecordingsEnum(self.default_number_of_recordings),
             )
 
         if self.number_of_decimals not in range(1, 11):
-            raise ValueError(
-                "The number of decimals should be an integer between 1 and 10."
-            )
+            msg = "The number of decimals should be an integer between 1 and 10."
+            raise ValueError(msg)
 
         if self.wait_sec_stop_commands <= 0:
-            raise ValueError(
+            msg = (
                 "Wait time after subsequent commands during stop must be be a "
                 "positive value (in seconds)."
             )
+            raise ValueError(msg)
 
 
 class Heinzinger(SingleCommDevice, DeprecatedHeinzingerMixin):
@@ -88,7 +89,7 @@ class Heinzinger(SingleCommDevice, DeprecatedHeinzingerMixin):
 
         # Status of the voltage output (it has to be updated via the output = True and
         # output = False because querying it is not supported)
-        self._output_status: Optional[bool] = None
+        self._output_status: bool | None = None
 
         # Serial number of the device (will be retrieved after com is opened)
         self._serial_number: str = ""
@@ -109,7 +110,7 @@ class Heinzinger(SingleCommDevice, DeprecatedHeinzingerMixin):
         # identify current range, because unit is always A
         self._current_multiplier: Number = 0
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return (
             f"HeinzingerPNC({self._serial_number}), with "
             f"HeinzingerDI({self._interface_version})"
@@ -130,7 +131,7 @@ class Heinzinger(SingleCommDevice, DeprecatedHeinzingerMixin):
         :raises SerialCommunicationIOError: when communication port cannot be opened.
         """
 
-        logger.info("Starting device " + str(self))
+        logger.info(f"Starting device {self}")
         super().start()
 
         self._interface_version = self.get_interface_version()
@@ -172,8 +173,7 @@ class Heinzinger(SingleCommDevice, DeprecatedHeinzingerMixin):
             model = result.group()
             self._model = model
             # regex to find the nominal voltage and nominal current
-            match = re.search(regex_vc, model)
-            assert match  # already matched in regex_model expression
+            match = cast("re.Match", re.search(regex_vc, model))
             voltage = int(match.group(1))
             current = int(match.group(2))
             # the units of voltage (V) and current (A)
@@ -243,7 +243,7 @@ class Heinzinger(SingleCommDevice, DeprecatedHeinzingerMixin):
         return self._max_current
 
     @max_current.setter
-    def max_current(self, value: Optional[Number]):
+    def max_current(self, value: Number | None):
         """Maximal settable output current in A"""
         if value is None:
             # Reset the user-defined limit to the hardware limit
@@ -260,7 +260,7 @@ class Heinzinger(SingleCommDevice, DeprecatedHeinzingerMixin):
         return self._max_voltage
 
     @max_voltage.setter
-    def max_voltage(self, value: Optional[Number]):
+    def max_voltage(self, value: Number | None):
         """Maximal settable output voltage in V"""
         if value is None:
             # Reset the user-defined limit to the hardware limit
@@ -272,7 +272,7 @@ class Heinzinger(SingleCommDevice, DeprecatedHeinzingerMixin):
         self._max_voltage = value
 
     @property
-    def output(self) -> Optional[bool]:
+    def output(self) -> bool | None:
         """
         Switch DC voltage output on and updates the output status.
 
@@ -315,7 +315,7 @@ class Heinzinger(SingleCommDevice, DeprecatedHeinzingerMixin):
         return int(value)
 
     @number_of_recordings.setter
-    def number_of_recordings(self, value: Union[int, RecordingsEnum]) -> None:
+    def number_of_recordings(self, value: int | RecordingsEnum) -> None:
         """
         Sets the number of recordings the device is using for average value
         calculation. The possible values are 1, 2, 4, 8 and 16.
@@ -364,8 +364,8 @@ class Heinzinger(SingleCommDevice, DeprecatedHeinzingerMixin):
             )
             logger.error(msg)
             raise HeinzingerSetValueError(msg)
-        else:
-            logger.info(f"Output voltage of the Heinzinger PNC is set to: {value} V")
+
+        logger.info(f"Output voltage of the Heinzinger PNC is set to: {value} V")
 
     @property
     def set_voltage(self) -> Number:
@@ -426,8 +426,8 @@ class Heinzinger(SingleCommDevice, DeprecatedHeinzingerMixin):
             )
             logger.error(msg)
             raise HeinzingerSetValueError(msg)
-        else:
-            logger.info(f"Output current of the Heinzinger PNC is set to: {value} A")
+
+        logger.info(f"Output current of the Heinzinger PNC is set to: {value} A")
 
     @property
     def set_current(self) -> Number:
