@@ -20,12 +20,11 @@ To use this LabJack T-series devices wrapper:
    https://labjack.com/support/software/installers/ljm .
 
 """
+
 from __future__ import annotations
 
 import logging
-from collections.abc import Sequence
-from numbers import Real
-from typing import Optional, Union, cast
+from typing import TYPE_CHECKING, cast
 
 from aenum import Enum, IntEnum
 
@@ -34,9 +33,13 @@ from hvl_ccb.comm.labjack_ljm import LJMCommunication
 from hvl_ccb.dev import SingleCommDevice
 from hvl_ccb.dev.base import DeviceError
 from hvl_ccb.utils.enum import NameEnum, StrEnumBase
-from hvl_ccb.utils.typing import Number
 from hvl_ccb.utils.validation import validate_bool, validate_number
 
+if TYPE_CHECKING:
+    from collections.abc import Sequence
+
+    from hvl_ccb.utils.typing import Number
+
 logger = logging.getLogger(__name__)
 
 
@@ -45,16 +48,12 @@ class LabJackError(DeviceError):
     General Error for the LabJack device.
     """
 
-    pass
-
 
 class LabJackIdentifierDIOError(LabJackError):
     """
     Error indicating a wrong DIO identifier
     """
 
-    pass
-
 
 class LabJack(SingleCommDevice):
     """
@@ -82,12 +81,10 @@ class LabJack(SingleCommDevice):
         super().__init__(com, dev_config)
 
         # cached device type
-        self._device_type: Optional[labjack.DeviceType] = None
+        self._device_type: labjack.DeviceType | None = None
 
         # clock configuration for pulse out feature
-        self.configured_pulse_addresses: list[Union[str, labjack.TSeriesDIOChannel]] = (
-            []
-        )
+        self.configured_pulse_addresses: list[str | labjack.TSeriesDIOChannel] = []
 
     @staticmethod
     def default_com_cls():
@@ -98,7 +95,7 @@ class LabJack(SingleCommDevice):
         Start the Device.
         """
 
-        logger.info(f"Starting device {str(self)}")
+        logger.info(f"Starting device {self!s}")
         super().start()
 
     def stop(self) -> None:
@@ -106,10 +103,10 @@ class LabJack(SingleCommDevice):
         Stop the Device.
         """
 
-        logger.info(f"Stopping device {str(self)}")
+        logger.info(f"Stopping device {self!s}")
         super().stop()
 
-    def _read_float(self, *names: str) -> Union[float, Sequence[float]]:
+    def _read_float(self, *names: str) -> float | Sequence[float]:
         """
         Read a numeric value.
 
@@ -118,7 +115,7 @@ class LabJack(SingleCommDevice):
         """
         return self.com.read_name(*names, return_num_type=float)
 
-    def _read_int(self, *names: str) -> Union[int, Sequence[int]]:
+    def _read_int(self, *names: str) -> int | Sequence[int]:
         """
         Read an integer value.
 
@@ -134,7 +131,7 @@ class LabJack(SingleCommDevice):
         :return: Serial number.
         """
 
-        return cast(int, self._read_int("SERIAL_NUMBER"))
+        return cast("int", self._read_int("SERIAL_NUMBER"))
 
     def get_sbus_temp(self, number: int) -> float:
         """
@@ -144,7 +141,7 @@ class LabJack(SingleCommDevice):
         :return: temperature in Kelvin
         """
 
-        return cast(float, self._read_float(f"SBUS{number}_TEMP"))
+        return cast("float", self._read_float(f"SBUS{number}_TEMP"))
 
     def get_sbus_rh(self, number: int) -> float:
         """
@@ -154,9 +151,9 @@ class LabJack(SingleCommDevice):
         :return: relative humidity in %RH
         """
 
-        return cast(float, self._read_float(f"SBUS{number}_RH"))
+        return cast("float", self._read_float(f"SBUS{number}_RH"))
 
-    class AInRange(StrEnumBase, init="value_str"):  # type:ignore
+    class AInRange(StrEnumBase, init="value_str"):  # type: ignore[call-arg]
         TEN = "10"
         ONE = "1"
         ONE_TENTH = "0.1"
@@ -169,7 +166,7 @@ class LabJack(SingleCommDevice):
         def value(self) -> float:
             return float(self.value_str)
 
-    def get_ain(self, *channels: int) -> Union[float, Sequence[float]]:
+    def get_ain(self, *channels: int) -> float | Sequence[float]:
         """
         Read currently measured value (voltage, resistance, ...) from one or more
         of analog inputs.
@@ -192,7 +189,7 @@ class LabJack(SingleCommDevice):
         validate_number("DAC output voltage", value, (0.0, 5.0), logger=logger)
         self.com.write_name(f"DAC{channel}", value)
 
-    def set_ain_range(self, channel: int, vrange: Union[Real, AInRange]) -> None:
+    def set_ain_range(self, channel: int, vrange: Number | AInRange) -> None:
         """
         Set the range of an analog input port.
 
@@ -212,9 +209,10 @@ class LabJack(SingleCommDevice):
             resolution index to default value.
         """
 
-        ain_max_resolution = self.get_product_type().ain_max_resolution  # type: ignore
+        ain_max_resolution = self.get_product_type().ain_max_resolution
         if resolution not in range(ain_max_resolution + 1):
-            raise LabJackError(f"Not supported resolution index: {resolution}")
+            msg = f"Not supported resolution index: {resolution}"
+            raise LabJackError(msg)
 
         self.com.write_name(f"AIN{channel}_RESOLUTION_INDEX", resolution)
 
@@ -231,13 +229,15 @@ class LabJack(SingleCommDevice):
         """
 
         if pos_channel not in range(13):
-            raise LabJackError(f"Not supported pos_channel: {pos_channel}")
+            msg = f"Not supported pos_channel: {pos_channel}"
+            raise LabJackError(msg)
 
         if pos_channel % 2 != 0:
-            raise LabJackError(
+            msg = (
                 "AIN pos_channel for positive part of differential pair"
                 f" must be even: {pos_channel}"
             )
+            raise LabJackError(msg)
 
         neg_channel = pos_channel + 1
 
@@ -245,7 +245,7 @@ class LabJack(SingleCommDevice):
             f"AIN{pos_channel}_NEGATIVE_CH", neg_channel if differential else 199
         )
 
-    class ThermocoupleType(NameEnum, init="ef_index"):  # type:ignore
+    class ThermocoupleType(NameEnum, init="ef_index"):  # type: ignore[call-arg]
         """
         Thermocouple type; NONE means disable thermocouple mode.
         """
@@ -262,7 +262,7 @@ class LabJack(SingleCommDevice):
         PT500 = 41
         PT1000 = 42
 
-    class CjcType(NameEnum, init="slope offset"):  # type:ignore
+    class CjcType(NameEnum, init="slope offset"):  # type: ignore[call-arg]
         """
         CJC slope and offset
         """
@@ -270,7 +270,7 @@ class LabJack(SingleCommDevice):
         internal = 1, 0
         lm34 = 55.56, 255.37
 
-    class TemperatureUnit(NameEnum, init="ef_config_a"):  # type:ignore
+    class TemperatureUnit(NameEnum, init="ef_config_a"):  # type: ignore[call-arg]
         """
         Temperature unit (to be returned)
         """
@@ -282,12 +282,12 @@ class LabJack(SingleCommDevice):
     def set_ain_thermocouple(
         self,
         pos_channel: int,
-        thermocouple: Union[None, str, ThermocoupleType],
+        thermocouple: None | str | ThermocoupleType,
         cjc_address: int = 60050,
-        cjc_type: Union[str, CjcType] = (CjcType.internal),  # type: ignore
-        vrange: Union[Real, AInRange] = (AInRange.ONE_HUNDREDTH),  # type: ignore
+        cjc_type: str | CjcType = (CjcType.internal),  # type: ignore[assignment]
+        vrange: Number | AInRange = (AInRange.ONE_HUNDREDTH),  # type: ignore[assignment]
         resolution: int = 10,
-        unit: Union[str, TemperatureUnit] = (TemperatureUnit.K),  # type: ignore
+        unit: str | TemperatureUnit = (TemperatureUnit.K),  # type: ignore[assignment]
     ) -> None:
         """
         Set the analog input channel to thermocouple mode.
@@ -305,7 +305,7 @@ class LabJack(SingleCommDevice):
         """
 
         if thermocouple is None:
-            thermocouple = self.ThermocoupleType.NONE  # type: ignore
+            thermocouple = self.ThermocoupleType.NONE  # type: ignore[assignment]
 
         thermocouple = self.ThermocoupleType(thermocouple)
 
@@ -346,7 +346,7 @@ class LabJack(SingleCommDevice):
         :return: temperature in specified unit
         """
 
-        return round(cast(float, self._read_float(f"AIN{pos_channel}_EF_READ_A")), 2)
+        return round(cast("float", self._read_float(f"AIN{pos_channel}_EF_READ_A")), 2)
 
     class DIOStatus(IntEnum):
         """
@@ -356,7 +356,7 @@ class LabJack(SingleCommDevice):
         LOW = 0
         HIGH = 1
 
-    def set_digital_output(self, address: str, state: Union[int, DIOStatus]) -> None:
+    def set_digital_output(self, address: str, state: int | DIOStatus) -> None:
         """
         Set the value of a digital output.
 
@@ -365,7 +365,7 @@ class LabJack(SingleCommDevice):
             value
         """
         dt = self.get_product_type()
-        if address not in (dt.dio):  # type: ignore
+        if address not in (dt.dio):
             raise LabJackIdentifierDIOError
         state = self.DIOStatus(state)
         self.com.write_name(address, state)
@@ -373,7 +373,7 @@ class LabJack(SingleCommDevice):
     DIOChannel = labjack.TSeriesDIOChannel
 
     def get_digital_input(
-        self, address: Union[str, labjack.TSeriesDIOChannel]
+        self, address: str | labjack.TSeriesDIOChannel
     ) -> LabJack.DIOStatus:
         """
         Get the value of a digital input.
@@ -385,19 +385,21 @@ class LabJack(SingleCommDevice):
         if not isinstance(address, self.DIOChannel):
             address = self.DIOChannel(address)
         dt = self.get_product_type()
-        if address not in (dt.dio):  # type: ignore
-            dt_name = dt.name  # type: ignore
-            raise LabJackIdentifierDIOError(
+        if address not in (dt.dio):
+            dt_name = dt.name
+            msg = (
                 f"DIO {address.name} is not available for this device type: {dt_name}."
             )
+            raise LabJackIdentifierDIOError(msg)
         try:
             ret = self._read_int(address.name)
             return self.DIOStatus(ret)
-        except ValueError as e:
-            logger.error(str(e), exc_info=e)
-            raise LabJackIdentifierDIOError(f"Expected 0 or 1 return value, got {ret}.")
+        except ValueError as exc:
+            msg = f"Expected 0 or 1 return value, got {ret}."
+            logger.exception(msg)
+            raise LabJackIdentifierDIOError(msg) from exc
 
-    class CalMicroAmpere(Enum, init="value current_source_query"):  # type: ignore
+    class CalMicroAmpere(Enum, init="value current_source_query"):  # type: ignore[call-arg]
         """
         Pre-defined microampere (uA) values for calibration current source query.
         """
@@ -405,7 +407,7 @@ class LabJack(SingleCommDevice):
         TEN = "10uA", "CURRENT_SOURCE_10UA_CAL_VALUE"
         TWO_HUNDRED = "200uA", "CURRENT_SOURCE_200UA_CAL_VALUE"
 
-    def get_cal_current_source(self, name: Union[str, CalMicroAmpere]) -> float:
+    def get_cal_current_source(self, name: str | CalMicroAmpere) -> float:
         """
         This function will return the calibration of the chosen current source,
         this ist not a measurement!
@@ -417,7 +419,7 @@ class LabJack(SingleCommDevice):
         """
         if not isinstance(name, self.CalMicroAmpere):
             name = self.CalMicroAmpere(name)
-        return cast(float, self._read_float(name.current_source_query))
+        return cast("float", self._read_float(name.current_source_query))
 
     def get_product_id(self) -> int:
         """
@@ -427,7 +429,7 @@ class LabJack(SingleCommDevice):
 
         :return: integer product ID of the device
         """
-        return cast(int, self._read_int("PRODUCT_ID"))
+        return cast("int", self._read_int("PRODUCT_ID"))
 
     def get_product_type(self, force_query_id: bool = False) -> labjack.DeviceType:
         """
@@ -446,8 +448,9 @@ class LabJack(SingleCommDevice):
             try:
                 device_type_or_list = self.DeviceType.get_by_p_id(self.get_product_id())
             except ValueError as e:
-                logger.error(str(e), exc_info=e)
-                raise LabJackIdentifierDIOError from e
+                msg = "Error: Unknown Product ID"
+                logger.exception(msg, exc_info=e)
+                raise LabJackIdentifierDIOError(msg) from e
             if isinstance(device_type_or_list, self.DeviceType):
                 device_type = device_type_or_list
             else:  # isinstance(device_type_or_list, list):
@@ -456,11 +459,12 @@ class LabJack(SingleCommDevice):
                 conf_device_type = getattr(self.com.config, "device_type", None)
                 if conf_device_type:
                     if conf_device_type not in device_type_list:
-                        raise LabJackIdentifierDIOError(
+                        msg = (
                             f"Configured devices type {conf_device_type!s} does not "
                             "match any of the unambiguously reported device types: "
                             f"{','.join(str(dt) for dt in device_type_list)}."
                         )
+                        raise LabJackIdentifierDIOError(msg)
                     device_type = conf_device_type
                 else:
                     device_type = device_type_list[0]
@@ -481,7 +485,7 @@ class LabJack(SingleCommDevice):
         return self.get_product_type(force_query_id=force_query_id).name
 
     def set_ain_resistance(
-        self, channel: int, vrange: Union[Real, AInRange], resolution: int
+        self, channel: int, vrange: Number | AInRange, resolution: int
     ) -> None:
         """
         Set the specified channel to resistance mode. It utilized the 200uA current
@@ -506,7 +510,7 @@ class LabJack(SingleCommDevice):
         :param channel: channel with resistor
         :return: resistance value with 2 decimal places
         """
-        return round(cast(float, self._read_float(f"AIN{channel}_EF_READ_A")), 2)
+        return round(cast("float", self._read_float(f"AIN{channel}_EF_READ_A")), 2)
 
     class ClockFrequency(IntEnum):
         """
@@ -564,15 +568,14 @@ class LabJack(SingleCommDevice):
         divisor, roll_value = self._clock_config.values()
         clock_frequency = self.ClockFrequency.MAXIMUM / divisor
         clock_period = roll_value / clock_frequency
-        clock_settings = {
+        return {
             "clock_frequency": clock_frequency,
             "clock_period": clock_period,
         }
-        return clock_settings
 
     def set_clock(
         self,
-        clock_frequency: Union[Number, ClockFrequency] = 10_000_000,
+        clock_frequency: Number | ClockFrequency = 10_000_000,
         clock_period: Number = 1,
     ) -> None:
         """
@@ -610,7 +613,7 @@ class LabJack(SingleCommDevice):
 
     def config_high_pulse(
         self,
-        address: Union[str, labjack.TSeriesDIOChannel],
+        address: str | labjack.TSeriesDIOChannel,
         t_start: Number,
         t_width: Number,
         n_pulses: int = 1,
@@ -635,7 +638,7 @@ class LabJack(SingleCommDevice):
         device_type = self.get_product_type()
         if address not in device_type.pulse_out_addr:
             msg = f"{address} does not support pulse feature"
-            logging.error(msg)
+            logger.error(msg)
             raise LabJackError(msg)
 
         clock_settings = self.get_clock()
@@ -659,21 +662,23 @@ class LabJack(SingleCommDevice):
         addr = address.address
 
         self.enable_clock(False)
-        self.com.write_names({
-            f"DIO{addr}": 0,
-            f"DIO{addr}_EF_ENABLE": 0,
-            f"DIO{addr}_EF_OPTIONS": 0,
-            f"DIO{addr}_EF_INDEX": 2,
-            f"DIO{addr}_EF_CONFIG_B": start_tick,
-            f"DIO{addr}_EF_CONFIG_A": end_tick,
-            f"DIO{addr}_EF_CONFIG_C": n_pulses,
-        })
+        self.com.write_names(
+            {
+                f"DIO{addr}": 0,
+                f"DIO{addr}_EF_ENABLE": 0,
+                f"DIO{addr}_EF_OPTIONS": 0,
+                f"DIO{addr}_EF_INDEX": 2,
+                f"DIO{addr}_EF_CONFIG_B": start_tick,
+                f"DIO{addr}_EF_CONFIG_A": end_tick,
+                f"DIO{addr}_EF_CONFIG_C": n_pulses,
+            }
+        )
 
         if address not in self.configured_pulse_addresses:
             self.configured_pulse_addresses.append(address)
         logger.info(f"Pulse configured for {address}")
 
-    def send_pulses(self, *addresses: Union[str, labjack.TSeriesDIOChannel]) -> None:
+    def send_pulses(self, *addresses: str | labjack.TSeriesDIOChannel) -> None:
         """
         Sends pre-configured pulses for specified addresses.
         :param addresses: tuple of FIO addresses
@@ -685,7 +690,7 @@ class LabJack(SingleCommDevice):
                 address = self.DIOChannel(address)
             if address not in self.configured_pulse_addresses:
                 msg = f"No pulse configured for {address}"
-                logging.error(msg)
+                logger.error(msg)
                 raise LabJackError(msg)
             address_list.append(address.address)
 
@@ -697,7 +702,7 @@ class LabJack(SingleCommDevice):
         logger.info(f"Pulses sent on {addresses}")
 
     def disable_pulses(
-        self, *addresses: Optional[Union[str, labjack.TSeriesDIOChannel]]
+        self, *addresses: str | labjack.TSeriesDIOChannel | None
     ) -> None:
         """
         Disable previously configured pulse channels.
@@ -712,7 +717,7 @@ class LabJack(SingleCommDevice):
             if not isinstance(address, self.DIOChannel):
                 address = self.DIOChannel(address)
             if address not in self.configured_pulse_addresses:
-                logging.warning(f"No pulse configured for {address}")
+                logger.warning(f"No pulse configured for {address}")
                 continue
             self.com.write_name(f"DIO{address.address}_EF_ENABLE", 0)
             self.configured_pulse_addresses.remove(address.name)
