@@ -13,7 +13,7 @@ measurement/activeline/controllers/
 
 import logging
 from enum import Enum, IntEnum
-from typing import Union, cast
+from typing import cast
 
 from hvl_ccb.comm.serial import (
     SerialCommunication,
@@ -35,8 +35,6 @@ class PfeifferTPGError(DeviceError):
     Error with the Pfeiffer TPG Controller.
     """
 
-    pass
-
 
 @configdataclass
 class PfeifferTPGSerialCommunicationConfig(SerialCommunicationConfig):
@@ -44,15 +42,13 @@ class PfeifferTPGSerialCommunicationConfig(SerialCommunicationConfig):
     baudrate: int = 9600
 
     #: Pfeiffer TPG controllers do not use parity
-    parity: Union[str, SerialCommunicationParity] = SerialCommunicationParity.NONE
+    parity: str | SerialCommunicationParity = SerialCommunicationParity.NONE
 
     #: Pfeiffer TPG controllers use one stop bit
-    stopbits: Union[int, SerialCommunicationStopbits] = SerialCommunicationStopbits.ONE
+    stopbits: int | SerialCommunicationStopbits = SerialCommunicationStopbits.ONE
 
     #: One byte is eight bits long
-    bytesize: Union[int, SerialCommunicationBytesize] = (
-        SerialCommunicationBytesize.EIGHTBITS
-    )
+    bytesize: int | SerialCommunicationBytesize = SerialCommunicationBytesize.EIGHTBITS
 
     #: The terminator is <CR><LF>
     terminator: bytes = b"\r\n"
@@ -67,7 +63,7 @@ class PfeifferTPGSerialCommunication(SerialCommunication):
     Already predefines device-specific protocol parameters in config.
     """
 
-    def __init__(self, configuration):
+    def __init__(self, configuration) -> None:
         super().__init__(configuration)
 
     @staticmethod
@@ -135,8 +131,8 @@ class PfeifferTPGConfig:
     Device configuration dataclass for Pfeiffer TPG controllers.
     """
 
-    class Model(NameEnum, init="full_scale_ranges"):  # type:ignore
-        TPG25xA = {
+    class Model(NameEnum, init="full_scale_ranges"):  # type: ignore[call-arg]
+        TPG25xA = {  # noqa: RUF012
             1: 0,
             10: 1,
             100: 2,
@@ -147,7 +143,7 @@ class PfeifferTPGConfig:
             50000: 7,
             0.1: 8,
         }
-        TPGx6x = {
+        TPGx6x = {  # noqa: RUF012
             0.01: 0,
             0.1: 1,
             1: 2,
@@ -175,20 +171,21 @@ class PfeifferTPGConfig:
             """
             # Explicit check because otherwise we get `True` for instance for `float`
             if not isinstance(v, str):
-                raise TypeError(f"Expected `str`, got `{type(v)}` instead.")
+                msg = f"Expected `str`, got `{type(v)}` instead."
+                raise TypeError(msg)
             try:
                 return int(v) in self.full_scale_ranges_reversed
             except ValueError as e:
-                logger.error(str(e), exc_info=e)
+                logger.exception("Given string is not a valid scale range", exc_info=e)
                 return False
 
     # model of the TPG (determines which lookup table to use for the
     # full scale range)
-    model: Union[str, Model] = Model.TPG25xA  # type: ignore
+    model: str | Model = Model.TPG25xA  # type: ignore[assignment]
 
-    def clean_values(self):
+    def clean_values(self) -> None:
         if not isinstance(self.model, self.Model):
-            self.force_value("model", self.Model(self.model))
+            self.force_value("model", self.Model(self.model))  # type: ignore[attr-defined]
 
 
 class PfeifferTPG(SingleCommDevice):
@@ -196,7 +193,7 @@ class PfeifferTPG(SingleCommDevice):
     Pfeiffer TPG control unit device class
     """
 
-    SensorTypes = Enum(  # type: ignore
+    SensorTypes = Enum(
         value="SensorTypes",
         names=[
             ("TPR/PCR Pirani Gauge", 1),
@@ -239,15 +236,15 @@ class PfeifferTPG(SingleCommDevice):
         # list of sensors connected to the TPG
         self.sensors: list[str] = []
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"Pfeiffer TPG with {self.number_of_sensors} sensors: {self.sensors}"
 
     @property
-    def number_of_sensors(self):
+    def number_of_sensors(self) -> int:
         return len(self.sensors)
 
     @property
-    def unit(self):
+    def unit(self) -> str:
         """
         The pressure unit of readings is always mbar, regardless of the display unit.
         """
@@ -294,8 +291,8 @@ class PfeifferTPG(SingleCommDevice):
 
         try:
             answer = self.com.query("TID")
-        except PfeifferTPGError as e:
-            logger.error("Pressure sensor identification failed.", exc_info=e)
+        except PfeifferTPGError:
+            logger.exception("Pressure sensor identification failed.")
             raise
 
         # try matching the sensors:
@@ -303,8 +300,8 @@ class PfeifferTPG(SingleCommDevice):
         for s in answer.split(","):
             try:
                 sensors.append(self.SensorTypes[s].name)
-            except KeyError as e:
-                logger.error(str(e), exc_info=e)
+            except KeyError:  # noqa: PERF203 Continue loop after exception
+                logger.exception("Unknown sensor")
                 sensors.append("Unknown")
         self.sensors = sensors
         # identification successful:
@@ -333,7 +330,7 @@ class PfeifferTPG(SingleCommDevice):
         try:
             answer = self.com.query(f"PR{channel}")
         except PfeifferTPGError as e:
-            logger.error(f"Reading sensor {channel} failed.", exc_info=e)
+            logger.exception(f"Reading sensor {channel} failed.", exc_info=e)
             raise
 
         status, measurement = answer.split(",")
@@ -363,7 +360,7 @@ class PfeifferTPG(SingleCommDevice):
         try:
             answer = self.com.query("PRX")
         except PfeifferTPGError as e:
-            logger.error(
+            logger.exception(
                 "Getting pressure reading from all sensors failed "
                 "(this command is not available on all TGP models).",
                 exc_info=e,
@@ -391,10 +388,11 @@ class PfeifferTPG(SingleCommDevice):
         :raises PfeifferTPGError: if command fails
         """
         if len(fsr) != self.number_of_sensors:
-            raise ValueError(
+            msg = (
                 f"Argument fsr should be of length {self.number_of_sensors}. "
                 f"Received length {len(fsr)}."
             )
+            raise ValueError(msg)
 
         possible_values_map = (
             self.config.model.full_scale_ranges_reversed
@@ -403,11 +401,12 @@ class PfeifferTPG(SingleCommDevice):
         )
         wrong_values = [v for v in fsr if v not in possible_values_map]
         if wrong_values:
-            raise ValueError(
+            msg = (
                 f"Argument fsr contains invalid values: {wrong_values}. Accepted "
                 f"values are {list(possible_values_map.items())}"
                 f"{'' if unitless else ' mbar'}."
             )
+            raise ValueError(msg)
 
         str_fsr = ",".join(
             [str(f if unitless else possible_values_map[f]) for f in fsr]
@@ -416,8 +415,8 @@ class PfeifferTPG(SingleCommDevice):
             self.com.send_command(f"FSR,{str_fsr}")
             logger.info(f"Set sensors full scale to {fsr} (unitless) respectively.")
         except PfeifferTPGError as e:
-            logger.error("Setting sensors full scale failed.", exc_info=e)
-            raise e
+            logger.exception("Setting sensors full scale failed.", exc_info=e)
+            raise
 
     def _get_full_scale(self, unitless: bool) -> list[Number]:
         """
@@ -435,7 +434,9 @@ class PfeifferTPG(SingleCommDevice):
         try:
             answer = self.com.query("FSR")
         except PfeifferTPGError as e:
-            logger.error("Query full scale range of all sensors failed.", exc_info=e)
+            logger.exception(
+                "Query full scale range of all sensors failed.", exc_info=e
+            )
             raise
 
         answer_values = answer.split(",")
@@ -445,11 +446,12 @@ class PfeifferTPG(SingleCommDevice):
             if not self.config.model.is_valid_scale_range_reversed_str(v)
         ]
         if wrong_values:
-            raise PfeifferTPGError(
+            msg = (
                 "The controller returned the full unitless scale range values: "
                 f"{answer}. The values {wrong_values} are invalid. Accepted values are "
                 f"{list(self.config.model.full_scale_ranges_reversed.keys())}."
             )
+            raise PfeifferTPGError(msg)
 
         fsr = [
             int(v) if unitless else self.config.model.full_scale_ranges_reversed[int(v)]
@@ -470,7 +472,7 @@ class PfeifferTPG(SingleCommDevice):
         :raises SerialCommunicationIOError: when communication port is not opened
         :raises PfeifferTPGError: if command fails
         """
-        self._set_full_scale(cast(list[Number], fsr), True)
+        self._set_full_scale(cast("list[Number]", fsr), True)
 
     def get_full_scale_unitless(self) -> list[int]:
         """
@@ -481,7 +483,7 @@ class PfeifferTPG(SingleCommDevice):
         :raises SerialCommunicationIOError: when communication port is not opened
         :raises PfeifferTPGError: if command fails
         """
-        return cast(list[int], self._get_full_scale(True))
+        return cast("list[int]", self._get_full_scale(True))
 
     def set_full_scale_mbar(self, fsr: list[Number]) -> None:
         """
