@@ -5,16 +5,16 @@ Device class for controlling a Schneider Electric ILS2T stepper drive over modbu
 """
 
 import logging
+import struct
+import sys
 from datetime import timedelta
 from enum import Flag, IntEnum
-from numbers import Integral
 from time import sleep, time
-from typing import Any, Optional, cast
+from typing import Any, ClassVar, cast
 
 import aenum
 from bitstring import BitArray
-from pymodbus.constants import Endian
-from pymodbus.payload import BinaryPayloadBuilder, BinaryPayloadDecoder
+from pymodbus.client import ModbusTcpClient
 
 from hvl_ccb.comm.modbus_tcp import (
     ModbusTcpCommunication,
@@ -33,24 +33,18 @@ class ILS2TError(DeviceError):
     Error to indicate problems with the SE ILS2T stepper motor.
     """
 
-    pass
-
 
 class IoScanningModeValueError(ILS2TError):
     """
     Erorr to indicate that the selected IO scanning mode is invalid.
     """
 
-    pass
-
 
 class ScalingFactorValueError(ILS2TError):
     """
     Error to indicate that a scaling factor value is invalid.
     """
 
-    pass
-
 
 @configdataclass
 class ILS2TModbusTcpCommunicationConfig(ModbusTcpCommunicationConfig):
@@ -83,45 +77,47 @@ class ILS2TConfig:
     #: initial maximum RPM for the motor, can be set up to 3000 RPM. The user is
     #: allowed to set a new max RPM at runtime using :meth:`ILS2T.set_max_rpm`,
     #: but the value must never exceed this configuration setting.
-    rpm_max_init: Integral = cast(Integral, 1500)
+    rpm_max_init: int = 1500
     wait_sec_post_enable: Number = 1
     wait_sec_max_disable: Number = 10
     wait_sec_post_cannot_disable: Number = 1
     wait_sec_post_relative_step: Number = 2
     wait_sec_post_absolute_position: Number = 2
 
-    def clean_values(self):
+    def clean_values(self) -> None:
         if not 0 < self.rpm_max_init <= 3000:
-            raise ValueError(
-                "Maximum RPM for the motor must be integer number between 1 and 3000."
-            )
+            msg = "Maximum RPM for the motor must be integer number between 1 and 3000."
+            raise ValueError(msg)
         if self.wait_sec_post_enable <= 0:
-            raise ValueError(
-                "Wait time post motor enabling must be a positive value (in seconds)."
-            )
+            msg = "Wait time post motor enabling must be a positive value (in seconds)."
+            raise ValueError(msg)
         if self.wait_sec_max_disable < 0:
-            raise ValueError(
+            msg = (
                 "Maximal wait time for attempting to disable motor must be a "
                 "non-negative value (in seconds)."
             )
+            raise ValueError(msg)
         if self.wait_sec_post_cannot_disable <= 0:
-            raise ValueError(
+            msg = (
                 "Wait time post failed motor disable attempt must be a positive value "
                 "(in seconds)."
             )
+            raise ValueError(msg)
         if self.wait_sec_post_relative_step <= 0:
-            raise ValueError(
+            msg = (
                 "Wait time post motor relative step must be a positive value "
                 "(in seconds)."
             )
+            raise ValueError(msg)
         if self.wait_sec_post_absolute_position <= 0:
-            raise ValueError(
+            msg = (
                 "Wait time post motor absolute position change must be a positive "
                 "value (in seconds)."
             )
+            raise ValueError(msg)
 
 
-class ILS2TRegDatatype(aenum.Enum, init="min max"):  # type: ignore
+class ILS2TRegDatatype(aenum.Enum, init="min max"):  # type: ignore[call-arg]
     """
     Modbus Register Datatypes for Schneider Electric ILS2T stepper drive.
 
@@ -208,19 +204,38 @@ class ILS2T(SingleCommDevice):
     """
 
     # Note: don't use IntFlag here - it allows other then enumerated values
-    class Ref16Jog(Flag):
-        """
-        Allowed values for ILS2T ref_16 register (the shown values are the integer
-        representation of the bits), all in Jog mode = 1
-        """
+    # The behaviour changed with py311
+    if sys.version_info < (3, 11):
 
-        NONE = 0
-        POS = 1
-        NEG = 2
-        FAST = 4
-        # allowed combinations
-        POS_FAST = POS | FAST
-        NEG_FAST = NEG | FAST
+        class Ref16Jog(Flag):
+            """
+            Allowed values for ILS2T ref_16 register (the shown values are the integer
+            representation of the bits), all in Jog mode = 1
+            """
+
+            NONE = 0
+            POS = 1
+            NEG = 2
+            FAST = 4
+            # allowed combinations
+            POS_FAST = POS | FAST
+            NEG_FAST = NEG | FAST
+    else:
+        from enum import STRICT
+
+        class Ref16Jog(Flag, boundary=STRICT):
+            """
+            Allowed values for ILS2T ref_16 register (the shown values are the integer
+            representation of the bits), all in Jog mode = 1
+            """
+
+            NONE = 0
+            POS = 1
+            NEG = 2
+            FAST = 4
+            # allowed combinations
+            POS_FAST = POS | FAST
+            NEG_FAST = NEG | FAST
 
     class State(IntEnum):
         """
@@ -231,7 +246,7 @@ class ILS2T(SingleCommDevice):
         READY = 4
         ON = 6
 
-    DEFAULT_IO_SCANNING_CONTROL_VALUES = {
+    DEFAULT_IO_SCANNING_CONTROL_VALUES: ClassVar[dict[str, Any]] = {
         "action": ActionsPtp.RELATIVE_POSITION_MOTOR.value,
         "mode": Mode.PTP.value,
         "disable_driver_di": 0,
@@ -276,12 +291,12 @@ class ILS2T(SingleCommDevice):
         Start this device.
         """
 
-        logger.info("Starting device " + str(self))
+        logger.info(f"Starting device {self}")
         try:
             # try opening the port
             super().start()
-        except ModbusTcpConnectionFailedError as exc:
-            logger.error(str(exc), exc_info=exc)
+        except ModbusTcpConnectionFailedError:
+            logger.exception("Error with ModbusTCP Connection")
             raise
 
         # writing 1 to register ACCESS_ENABLE allows to use the IO scanning mode.
@@ -297,12 +312,12 @@ class ILS2T(SingleCommDevice):
         closes the communication protocol.
         """
 
-        logger.info("Stopping device " + str(self))
+        logger.info(f"Stopping device {self}")
         self.disable()
         self.com.write_registers(self.RegAddr.ACCESS_ENABLE.value, [0, 0])
         super().stop()
 
-    def get_status(self) -> dict[str, int]:
+    def get_status(self) -> dict[str, int | list[bool]]:
         """
         Perform an IO Scanning read and return the status of the motor.
 
@@ -339,40 +354,54 @@ class ILS2T(SingleCommDevice):
 
         action_bits = f"{cleaned_io_scanning_mode['action']:03b}"
         mode_bits = f"{cleaned_io_scanning_mode['mode']:04b}"
-        builder = BinaryPayloadBuilder(byteorder=Endian.BIG, wordorder=Endian.BIG)
+        builder = []
 
-        # add the first byte: Drive control
-        builder.add_bits([
-            cleaned_io_scanning_mode["disable_driver_di"],
-            cleaned_io_scanning_mode["enable_driver_en"],
-            cleaned_io_scanning_mode["quick_stop_qs"],
-            cleaned_io_scanning_mode["fault_reset_fr"],
-            0,  # has to be 0 per default, no meaning
-            cleaned_io_scanning_mode["execute_stop_sh"],
-            cleaned_io_scanning_mode["reset_stop_ch"],
-            cleaned_io_scanning_mode["continue_after_stop_cu"],
-        ])
-
-        # add the second byte: Mode control
-        builder.add_bits([
-            int(mode_bits[3]),
-            int(mode_bits[2]),
-            int(mode_bits[1]),
-            int(mode_bits[0]),
-            int(action_bits[2]),
-            int(action_bits[1]),
-            int(action_bits[0]),
-            self._mode_toggle_mt,
-        ])
+        builder.extend(
+            ModbusTcpClient.convert_to_registers(
+                value=[
+                    # add the first byte: Drive control
+                    cleaned_io_scanning_mode["disable_driver_di"],
+                    cleaned_io_scanning_mode["enable_driver_en"],
+                    cleaned_io_scanning_mode["quick_stop_qs"],
+                    cleaned_io_scanning_mode["fault_reset_fr"],
+                    0,  # has to be 0 per default, no meaning
+                    cleaned_io_scanning_mode["execute_stop_sh"],
+                    cleaned_io_scanning_mode["reset_stop_ch"],
+                    cleaned_io_scanning_mode["continue_after_stop_cu"],
+                    # add the second byte: Mode control
+                    int(mode_bits[3]),
+                    int(mode_bits[2]),
+                    int(mode_bits[1]),
+                    int(mode_bits[0]),
+                    int(action_bits[2]),
+                    int(action_bits[1]),
+                    int(action_bits[0]),
+                    self._mode_toggle_mt,
+                ],
+                data_type=ModbusTcpClient.DATATYPE.BITS,
+                word_order="big",
+            )
+        )
 
         # add the third and fourth byte:
         # Ref_16 (either JOG direction/speed, or RPM...)
-        builder.add_16bit_uint(cleaned_io_scanning_mode["ref_16"])
+        builder.extend(
+            ModbusTcpClient.convert_to_registers(
+                value=cleaned_io_scanning_mode["ref_16"],
+                data_type=ModbusTcpClient.DATATYPE.UINT16,
+                word_order="big",
+            )
+        )
 
         # add 4 bytes Ref_32, Target position
-        builder.add_32bit_int(cleaned_io_scanning_mode["ref_32"])
-
-        return builder.to_registers()
+        builder.extend(
+            ModbusTcpClient.convert_to_registers(
+                value=cleaned_io_scanning_mode["ref_32"],
+                data_type=ModbusTcpClient.DATATYPE.INT32,
+                word_order="big",
+            )
+        )
+        return builder
 
     def _clean_ioscanning_mode_values(
         self, io_scanning_values: dict[str, int]
@@ -393,34 +422,34 @@ class ILS2T(SingleCommDevice):
         all_keys = set(self.DEFAULT_IO_SCANNING_CONTROL_VALUES.keys())
         superfluous_keys = io_scanning_keys.difference(all_keys)
         if superfluous_keys:
-            raise ValueError(f"Unrecognized mode keys: {list(superfluous_keys)}")
+            msg = f"Unrecognized mode keys: {list(superfluous_keys)}"
+            raise ValueError(msg)
 
         # fill up io_scanning_values with defaults, if they are not set
         for mode_key, default_value in self.DEFAULT_IO_SCANNING_CONTROL_VALUES.items():
             if mode_key not in io_scanning_values:
-                io_scanning_values[mode_key] = cast(int, default_value)
+                io_scanning_values[mode_key] = cast("int", default_value)
 
         # perform checks depending on mode
         # JOG mode
         if io_scanning_values["mode"] == self.Mode.JOG:
             io_scanning_value = io_scanning_values["action"]
-            if not io_scanning_value == self.ACTION_JOG_VALUE:
-                raise IoScanningModeValueError(f"Wrong action: {io_scanning_value}")
+            if io_scanning_value != self.ACTION_JOG_VALUE:
+                msg = f"Wrong action: {io_scanning_value}"
+                raise IoScanningModeValueError(msg)
 
             io_scanning_value = io_scanning_values["ref_16"]
             try:
                 self.Ref16Jog(io_scanning_value)
-            except ValueError as e:
-                logger.error(str(e), exc_info=e)
-                raise IoScanningModeValueError(
-                    f"Wrong value in ref_16 ({io_scanning_value})"
-                )
+            except ValueError as exc:
+                msg = f"Wrong value in ref_16 ({io_scanning_value})"
+                logger.exception(msg)
+                raise IoScanningModeValueError(msg) from exc
 
             io_scanning_value = io_scanning_values["ref_32"]
-            if not io_scanning_value == 0:
-                raise IoScanningModeValueError(
-                    f"Wrong value in ref_32 ({io_scanning_value})"
-                )
+            if io_scanning_value != 0:
+                msg = f"Wrong value in ref_32 ({io_scanning_value})"
+                raise IoScanningModeValueError(msg)
 
             return io_scanning_values
 
@@ -429,26 +458,26 @@ class ILS2T(SingleCommDevice):
             io_scanning_value = io_scanning_values["action"]
             try:
                 self.ActionsPtp(io_scanning_value)
-            except ValueError as e:
-                logger.error(str(e), exc_info=e)
-                raise IoScanningModeValueError(f"Wrong action: {io_scanning_value}")
+            except ValueError as exc:
+                msg = f"Wrong action: {io_scanning_value}"
+                logger.exception(msg)
+                raise IoScanningModeValueError(msg) from exc
 
             io_scanning_value = io_scanning_values["ref_16"]
             if not self._is_valid_rpm(io_scanning_value):
-                raise IoScanningModeValueError(
-                    f"Wrong value in ref_16 ({io_scanning_value})"
-                )
+                msg = f"Wrong value in ref_16 ({io_scanning_value})"
+                raise IoScanningModeValueError(msg)
 
             io_scanning_value = io_scanning_values["ref_32"]
             if not self._is_int32(io_scanning_value):
-                raise IoScanningModeValueError(
-                    f"Wrong value in ref_32 ({io_scanning_value})"
-                )
+                msg = f"Wrong value in ref_32 ({io_scanning_value})"
+                raise IoScanningModeValueError(msg)
 
             return io_scanning_values
 
         # default
-        raise IoScanningModeValueError(f"Wrong mode: {io_scanning_values['mode']}")
+        msg = f"Wrong mode: {io_scanning_values['mode']}"
+        raise IoScanningModeValueError(msg)
 
     def _is_valid_rpm(self, num: int) -> bool:
         """
@@ -458,7 +487,7 @@ class ILS2T(SingleCommDevice):
         :return: `True` if `num` is a valid RPM value, `False` otherwise
         """
 
-        return isinstance(num, Integral) and 0 < num <= self.config.rpm_max_init
+        return isinstance(num, int) and 0 < num <= self.config.rpm_max_init
 
     @classmethod
     def _is_int32(cls, num: int) -> bool:
@@ -468,35 +497,47 @@ class ILS2T(SingleCommDevice):
         :param num: is the number to check.
         :return: check result.
         """
-        return isinstance(num, Integral) and cast(
-            ILS2TRegDatatype, ILS2TRegDatatype.INT32
+        return isinstance(num, int) and cast(
+            "ILS2TRegDatatype", ILS2TRegDatatype.INT32
         ).is_in_range(num)
 
     @staticmethod
-    def _decode_status_registers(registers: list[int]) -> dict[str, int]:
+    def _decode_status_registers(registers: list[int]) -> dict[str, int | list[bool]]:
         """
         Decodes the the status of the stepper drive, derived from IOscanning.
+        register 1 is decoded into "ref_16" (16-bit int)
+        register 2 and 3 together into "ref_32" (32-bit int)
+        the others are decoded into bit lists
 
         :param registers: List of 8 registers (6922-6930)
         :return: dict
         """
+        decoded = {}
 
-        decoder = BinaryPayloadDecoder.fromRegisters(registers, byteorder=Endian.BIG)
-        decoded = {
-            "drive_control": decoder.decode_bits(),
-            "mode_control": decoder.decode_bits(),
-            "ref_16": decoder.decode_16bit_int(),
-            "ref_32": decoder.decode_32bit_int(),
-            "drive_status_1": decoder.decode_bits(),
-            "drive_status_2": decoder.decode_bits(),
-            "mode_status": decoder.decode_bits(),
-            "drive_input": decoder.decode_bits(),
-            "action_word_1": decoder.decode_bits(),
-            "action_word_2": decoder.decode_bits(),
-            "special_function_1": decoder.decode_bits(),
-            "special_function_2": decoder.decode_bits(),
+        bit_list_registers = {
+            0: ("drive_control", "mode_control"),
+            4: ("drive_status_1", "drive_status_2"),
+            5: ("mode_status", "drive_input"),
+            6: ("action_word_1", "action_word_2"),
+            7: ("special_function_1", "special_function_2"),
         }
 
+        for idx, keys in bit_list_registers.items():
+            reg_bytes = registers[idx].to_bytes(2, byteorder="big")
+            bit_lists = [
+                [bool((byte >> bit_position) & 1) for bit_position in range(8)]
+                for byte in reg_bytes
+            ]
+            decoded[keys[0]], decoded[keys[1]] = bit_lists
+
+        # > means big-endian and h signed short int 2 bytes
+        decoded["ref_16"] = struct.unpack(">h", struct.pack(">h", registers[1]))[0]
+
+        # Combine register 2 and 3 into a 32-bit integer
+        # HH: two unsigned short int 2 bytes, I: big-endian unsigned int 4 bytes
+        byte_data = struct.pack(">HH", registers[2], registers[3])
+        decoded["ref_32"] = struct.unpack(">I", byte_data)[0]
+
         return {
             "mode": BitArray(decoded["mode_status"][3::-1]).int,
             "action": BitArray(decoded["mode_control"][6:3:-1]).int,
@@ -525,7 +566,7 @@ class ILS2T(SingleCommDevice):
 
         :param steps: Number of steps to turn the motor.
         """
-        max_step = self.RegDatatype.INT32.max  # type: ignore
+        max_step = self.RegDatatype.INT32.max  # type: ignore[attr-defined]
         # use _is_int32 instead?
         if not abs(steps) < max_step:
             logger.warning(f"number of steps is too big: {steps}")
@@ -547,7 +588,7 @@ class ILS2T(SingleCommDevice):
         :param position: absolute position of motor in user defined steps.
         """
 
-        max_position = self.RegDatatype.INT32.max  # type: ignore
+        max_position = self.RegDatatype.INT32.max  # type: ignore[attr-defined]
         # use _is_int32 instead?
         if not abs(position) < max_position:
             logger.warning(f"position is out of range: {position}")
@@ -579,7 +620,7 @@ class ILS2T(SingleCommDevice):
         if not as_expected:
             flt_dict = self.get_error_code()
             self.flt_list.append(flt_dict)
-            if "empty" in flt_dict[0].keys():
+            if "empty" in flt_dict[0]:
                 logger.warning(
                     "no error in drive, something different must have gone wrong"
                 )
@@ -657,7 +698,7 @@ class ILS2T(SingleCommDevice):
     def disable(
         self,
         log_warn: bool = True,
-        wait_sec_max: Optional[int] = None,
+        wait_sec_max: int | None = None,
     ) -> bool:
         """
         Disable the driver of the stepper motor and enable the brake.
@@ -738,11 +779,14 @@ class ILS2T(SingleCommDevice):
         :return: integer representation of the 32-bit register
         """
 
-        decoder = BinaryPayloadDecoder.fromRegisters(registers, byteorder=Endian.BIG)
         if signed:
-            return decoder.decode_32bit_int()
-        else:
-            return decoder.decode_32bit_uint()
+            return ModbusTcpClient.convert_from_registers(
+                registers=registers, data_type=ModbusTcpClient.DATATYPE.INT32
+            )
+
+        return ModbusTcpClient.convert_from_registers(
+            registers=registers, data_type=ModbusTcpClient.DATATYPE.UINT32
+        )
 
     def user_steps(self, steps: int = 16384, revolutions: int = 1) -> None:
         """
@@ -764,11 +808,22 @@ class ILS2T(SingleCommDevice):
             logger.error(err_msg)
             raise ScalingFactorValueError(err_msg)
 
-        builder = BinaryPayloadBuilder(byteorder=Endian.BIG, wordorder=Endian.BIG)
-        builder.add_32bit_int(steps)
-        builder.add_32bit_int(revolutions)
-        values = builder.to_registers()
-        self.com.write_registers(self.RegAddr.SCALE.value, values)
+        builder = []
+        builder.extend(
+            ModbusTcpClient.convert_to_registers(
+                value=steps,
+                data_type=ModbusTcpClient.DATATYPE.INT32,
+                word_order="big",
+            )
+        )
+        builder.extend(
+            ModbusTcpClient.convert_to_registers(
+                value=revolutions,
+                data_type=ModbusTcpClient.DATATYPE.INT32,
+                word_order="big",
+            )
+        )
+        self.com.write_registers(self.RegAddr.SCALE.value, builder)
 
     def quickstop(self) -> None:
         """
@@ -863,31 +918,72 @@ class ILS2T(SingleCommDevice):
         self.com.write_registers(self.RegAddr.FLT_MEM_RESET.value, [0, 1])
         for i in range(10):
             registers = self.com.read_input_registers(self.RegAddr.FLT_INFO.value, 22)
-            decoder = BinaryPayloadDecoder.fromRegisters(
-                registers, byteorder=Endian.BIG
-            )
             decoded = {
-                "ignored0": decoder.skip_bytes(2),
-                "error_code": decoder.decode_16bit_uint(),
-                "ignored1": decoder.skip_bytes(2),
-                "error_class": decoder.decode_16bit_uint(),
-                "error_time": decoder.decode_32bit_uint(),
-                "ignored2": decoder.skip_bytes(2),
-                "error_addition": decoder.decode_16bit_uint(),
-                "ignored3": decoder.skip_bytes(2),
-                "error_no_cycle": decoder.decode_16bit_uint(),
-                "ignored4": decoder.skip_bytes(2),
-                "error_after_enable": decoder.decode_16bit_uint(),
-                "ignored5": decoder.skip_bytes(2),
-                "error_voltage_dc": decoder.decode_16bit_uint(),
-                "ignored6": decoder.skip_bytes(2),
-                "error_rpm": decoder.decode_16bit_int(),
-                "ignored7": decoder.skip_bytes(2),
-                "error_current": decoder.decode_16bit_uint(),
-                "ignored8": decoder.skip_bytes(2),
-                "error_amplifier_temperature": decoder.decode_16bit_int(),
-                "ignored9": decoder.skip_bytes(2),
-                "error_device_temperature": decoder.decode_16bit_int(),
+                "ignored0": None,
+                "error_code": ModbusTcpClient.convert_from_registers(
+                    registers=registers[1:2],
+                    data_type=ModbusTcpClient.DATATYPE.UINT16,
+                    word_order="big",
+                ),
+                "ignored1": None,
+                "error_class": ModbusTcpClient.convert_from_registers(
+                    registers=registers[3:4],
+                    data_type=ModbusTcpClient.DATATYPE.UINT16,
+                    word_order="big",
+                ),
+                "error_time": ModbusTcpClient.convert_from_registers(
+                    registers=registers[4:6],
+                    data_type=ModbusTcpClient.DATATYPE.UINT32,
+                    word_order="big",
+                ),
+                "ignored2": None,
+                "error_addition": ModbusTcpClient.convert_from_registers(
+                    registers=registers[7:8],
+                    data_type=ModbusTcpClient.DATATYPE.UINT16,
+                    word_order="big",
+                ),
+                "ignored3": None,
+                "error_no_cycle": ModbusTcpClient.convert_from_registers(
+                    registers=registers[9:10],
+                    data_type=ModbusTcpClient.DATATYPE.UINT16,
+                    word_order="big",
+                ),
+                "ignored4": None,
+                "error_after_enable": ModbusTcpClient.convert_from_registers(
+                    registers=registers[11:12],
+                    data_type=ModbusTcpClient.DATATYPE.UINT16,
+                    word_order="big",
+                ),
+                "ignored5": None,
+                "error_voltage_dc": ModbusTcpClient.convert_from_registers(
+                    registers=registers[13:14],
+                    data_type=ModbusTcpClient.DATATYPE.UINT16,
+                    word_order="big",
+                ),
+                "ignored6": None,
+                "error_rpm": ModbusTcpClient.convert_from_registers(
+                    registers=registers[15:16],
+                    data_type=ModbusTcpClient.DATATYPE.INT16,
+                    word_order="big",
+                ),
+                "ignored7": None,
+                "error_current": ModbusTcpClient.convert_from_registers(
+                    registers=registers[17:18],
+                    data_type=ModbusTcpClient.DATATYPE.UINT16,
+                    word_order="big",
+                ),
+                "ignored8": None,
+                "error_amplifier_temperature": ModbusTcpClient.convert_from_registers(
+                    registers=registers[19:20],
+                    data_type=ModbusTcpClient.DATATYPE.INT16,
+                    word_order="big",
+                ),
+                "ignored9": None,
+                "error_device_temperature": ModbusTcpClient.convert_from_registers(
+                    registers=registers[21:22],
+                    data_type=ModbusTcpClient.DATATYPE.INT16,
+                    word_order="big",
+                ),
             }
             flt_dict = {
                 "error_code": hex(decoded["error_code"])[2:],
@@ -923,9 +1019,8 @@ class ILS2T(SingleCommDevice):
             self.DEFAULT_IO_SCANNING_CONTROL_VALUES["ref_16"] = rpm
             self.com.write_registers(self.RegAddr.RAMP_N_MAX.value, [0, rpm])
         else:
-            raise ILS2TError(
-                f"RPM out of range: {rpm} not in (0, {self.config.rpm_max_init}]"
-            )
+            msg = f"RPM out of range: {rpm} not in (0, {self.config.rpm_max_init}]"
+            raise ILS2TError(msg)
 
     def set_ramp_type(self, ramp_type: int = -1) -> None:
         """
@@ -945,10 +1040,15 @@ class ILS2T(SingleCommDevice):
         :param rpm_minute: revolution per minute per minute
         """
 
-        builder = BinaryPayloadBuilder(byteorder=Endian.BIG, wordorder=Endian.BIG)
-        builder.add_32bit_uint(rpm_minute)
-        values = builder.to_registers()
-        self.com.write_registers(self.RegAddr.RAMP_ACC.value, values)
+        builder = []
+        builder.extend(
+            ModbusTcpClient.convert_to_registers(
+                value=rpm_minute,
+                data_type=ModbusTcpClient.DATATYPE.UINT32,
+                word_order="big",
+            )
+        )
+        self.com.write_registers(self.RegAddr.RAMP_ACC.value, builder)
 
     def set_max_deceleration(self, rpm_minute: int) -> None:
         """
@@ -957,7 +1057,12 @@ class ILS2T(SingleCommDevice):
         :param rpm_minute: revolution per minute per minute
         """
 
-        builder = BinaryPayloadBuilder(byteorder=Endian.BIG, wordorder=Endian.BIG)
-        builder.add_32bit_uint(rpm_minute)
-        values = builder.to_registers()
-        self.com.write_registers(self.RegAddr.RAMP_DECEL.value, values)
+        builder = []
+        builder.extend(
+            ModbusTcpClient.convert_to_registers(
+                value=rpm_minute,
+                data_type=ModbusTcpClient.DATATYPE.UINT32,
+                word_order="big",
+            )
+        )
+        self.com.write_registers(self.RegAddr.RAMP_DECEL.value, builder)
