@@ -27,7 +27,7 @@ from .base import (  # noqa: F401
     TechnixError,
     TechnixSerialCommunication,
     TechnixSerialCommunicationConfig,
-    TechnixTelnetCommunication,
-    TechnixTelnetCommunicationConfig,
+    TechnixTcpCommunication,
+    TechnixTcpCommunicationConfig,
 )
 from .device import Technix, TechnixConfig  # noqa: F401
