@@ -1,12 +1,11 @@
 #  Copyright (c) ETH Zurich, SIS ID and HVL D-ITET
 #
-"""
-
-"""
+""" """
 
 import logging
 import time
-from typing import Generator, Optional, Union, cast
+from collections.abc import Generator
+from typing import cast
 
 import libtiepie as ltp
 import numpy as np
@@ -30,7 +29,7 @@ from .base import (
     get_device_by_serial_number,
     wrap_libtiepie_exception,
 )
-from .channel import SafeGround, TiePieOscilloscopeChannelConfig
+from .channel import TiePieOscilloscopeChannelConfig
 from .utils import PublicPropertiesReprMixin
 
 logger = logging.getLogger(__name__)
@@ -43,9 +42,7 @@ class TiePieOscilloscopeResolution(IntEnum):
     SIXTEEN_BIT = 16
 
 
-class TiePieOscilloscopeAutoResolutionModes(  # type:ignore
-    NameEnum, init="value description"
-):
+class TiePieOscilloscopeAutoResolutionModes(NameEnum, init="value description"):  # type: ignore[call-arg]
     UNKNOWN = ltp.ARM_UNKNOWN, "Unknown"
     DISABLED = ltp.ARM_DISABLED, "Disabled"
     NATIVEONLY = ltp.ARM_NATIVEONLY, "Native only"
@@ -71,7 +68,7 @@ class TiePieOscilloscopeConfig(PublicPropertiesReprMixin):
     Oscilloscope's configuration with cleaning of values in properties setters.
     """
 
-    def __init__(self, dev_osc: ltp_osc.Oscilloscope):
+    def __init__(self, dev_osc: ltp_osc.Oscilloscope) -> None:
         self.dev_osc: ltp_osc.Oscilloscope = dev_osc
         self.param_lim: TiePieOscilloscopeConfigLimits = TiePieOscilloscopeConfigLimits(
             dev_osc=dev_osc
@@ -111,14 +108,15 @@ class TiePieOscilloscopeConfig(PublicPropertiesReprMixin):
         )
 
         if not (float(record_length).is_integer()):
-            raise ValueError(
+            msg = (
                 "The record_length has to be a value, that can be cast "
                 "into an integer without significant precision loss; "
                 f"but {record_length:_d} was assigned."
             )
+            raise ValueError(msg)
 
         return cast(
-            int,
+            "int",
             _verify_via_libtiepie(self.dev_osc, "record_length", int(record_length)),
         )
 
@@ -134,7 +132,7 @@ class TiePieOscilloscopeConfig(PublicPropertiesReprMixin):
 
     @staticmethod
     def clean_resolution(
-        resolution: Union[int, TiePieOscilloscopeResolution]
+        resolution: int | TiePieOscilloscopeResolution,
     ) -> TiePieOscilloscopeResolution:
         if not isinstance(resolution, TiePieOscilloscopeResolution):
             validate_number("resolution", resolution, number_type=int, logger=logger)
@@ -145,7 +143,7 @@ class TiePieOscilloscopeConfig(PublicPropertiesReprMixin):
         return self.dev_osc.resolution
 
     @resolution.setter
-    def resolution(self, resolution: Union[int, TiePieOscilloscopeResolution]) -> None:
+    def resolution(self, resolution: int | TiePieOscilloscopeResolution) -> None:
         """
         Setter for resolution of the Oscilloscope.
 
@@ -158,7 +156,7 @@ class TiePieOscilloscopeConfig(PublicPropertiesReprMixin):
 
     @staticmethod
     def clean_auto_resolution_mode(
-        auto_resolution_mode: Union[int, TiePieOscilloscopeAutoResolutionModes]
+        auto_resolution_mode: int | TiePieOscilloscopeAutoResolutionModes,
     ) -> TiePieOscilloscopeAutoResolutionModes:
         if not isinstance(auto_resolution_mode, TiePieOscilloscopeAutoResolutionModes):
             validate_number(
@@ -211,7 +209,7 @@ class TiePieOscilloscopeConfig(PublicPropertiesReprMixin):
         logger.info(f"Sample rate is set to {sample_rate:_.3f} Sa/s.")
 
     @property
-    def sample_frequency(self):
+    def sample_frequency(self) -> float:
         """For backwards compatibility. Use `sample_rate` instead"""
         logger.warning(
             "The usage of `sample_frequency` is deprecated, use "
@@ -230,7 +228,7 @@ class TiePieOscilloscopeConfig(PublicPropertiesReprMixin):
         )
         self.sample_rate = sample_frequency
 
-    def clean_trigger_timeout(self, trigger_timeout: Optional[Number]) -> float:
+    def clean_trigger_timeout(self, trigger_timeout: Number | None) -> float:
         if trigger_timeout in (None, ltp.const.TO_INFINITY):
             # infinite timeout: `TO_INFINITY = -1` in `libtiepie.const`
             trigger_timeout = ltp.const.TO_INFINITY
@@ -242,18 +240,18 @@ class TiePieOscilloscopeConfig(PublicPropertiesReprMixin):
                 logger=logger,
             )
         trigger_timeout = _verify_via_libtiepie(
-            self.dev_osc.trigger, "timeout", cast(Number, trigger_timeout)
+            self.dev_osc.trigger, "timeout", cast("Number", trigger_timeout)
         )
         return float(trigger_timeout)
 
     @property
-    def trigger_timeout(self) -> Optional[float]:
+    def trigger_timeout(self) -> float | None:
         if self.dev_osc.trigger.timeout == ltp.const.TO_INFINITY:
             return None
         return self.dev_osc.trigger.timeout
 
     @trigger_timeout.setter
-    def trigger_timeout(self, trigger_timeout: Optional[Number]) -> None:
+    def trigger_timeout(self, trigger_timeout: Number | None) -> None:
         """
         Set trigger time-out.
 
@@ -303,9 +301,9 @@ class TiePieOscilloscope(SingleCommDevice):
         """
         super().__init__(com, dev_config)
 
-        self._osc: Optional[ltp_osc.Oscilloscope] = None
+        self._osc: ltp_osc.Oscilloscope | None = None
 
-        self.config_osc: Optional[TiePieOscilloscopeConfig] = None
+        self.config_osc: TiePieOscilloscopeConfig | None = None
         """
         Oscilloscope's dynamical configuration.
         """
@@ -323,18 +321,13 @@ class TiePieOscilloscope(SingleCommDevice):
         """
         Setup dynamical configuration for the connected oscilloscope.
         """
-        assert self._osc is not None
         self.config_osc = TiePieOscilloscopeConfig(
-            dev_osc=self._osc,
+            cast("ltp_osc.Oscilloscope", self._osc)
         )
         for n in range(1, self.n_channels + 1):
             self.config_osc_channel_dict[n] = TiePieOscilloscopeChannelConfig(
                 ch_number=n,
-                channel=self._osc.channels[n - 1],
-            )
-        if self.config_osc_channel_dict[1].has_safeground:
-            TiePieOscilloscopeChannelConfig.safeground_enabled = (  # type: ignore
-                SafeGround()
+                channel=cast("ltp_osc.Oscilloscope", self._osc).channels[n - 1],
             )
 
     def _osc_config_teardown(self) -> None:
@@ -370,7 +363,7 @@ class TiePieOscilloscope(SingleCommDevice):
         )
 
     @wrap_libtiepie_exception
-    def start(self) -> None:  # type: ignore
+    def start(self) -> None:
         """
         Start the oscilloscope.
         """
@@ -384,7 +377,7 @@ class TiePieOscilloscope(SingleCommDevice):
 
         # Check for block measurement support if required
         if self.config.require_block_measurement_support and not (
-            self._osc.measure_modes & ltp.MM_BLOCK  # type: ignore
+            self._osc.measure_modes & ltp.MM_BLOCK
         ):
             self._osc_close()
             msg = (
@@ -397,7 +390,7 @@ class TiePieOscilloscope(SingleCommDevice):
         self._osc_config_setup()
 
     @wrap_libtiepie_exception
-    def stop(self) -> None:  # type: ignore
+    def stop(self) -> None:
         """
         Stop the oscilloscope.
         """
@@ -452,12 +445,10 @@ class TiePieOscilloscope(SingleCommDevice):
         :raises TiePieError: when device is not started, when measurement is already
         running, or when status of underlying device gives an error.
         """
-        # make mypy happy w/ assert; `is None` check is already done in the
-        # `_require_dev_handle` method decorator
-        assert self._osc is not None
         if self.is_measurement_running():
-            raise TiePieError("TiePie measurement is already running")
-        self._osc.start()
+            msg = "TiePie measurement is already running"
+            raise TiePieError(msg)
+        cast("ltp_osc.Oscilloscope", self._osc).start()
 
     @wrap_libtiepie_exception
     @_require_dev_handle(TiePieDeviceType.OSCILLOSCOPE)
@@ -468,12 +459,10 @@ class TiePieOscilloscope(SingleCommDevice):
         :raises TiePieError: when device is not started, when measurement is not
         running, or when status of underlying device gives an error
         """
-        # make mypy happy w/ assert; `is None` check is already done in the
-        # `_require_dev_handle` method decorator
-        assert self._osc is not None
         if not self.is_measurement_running():
-            raise TiePieError("TiePie measurement is not running")
-        self._osc.stop()
+            msg = "TiePie measurement is not running"
+            raise TiePieError(msg)
+        cast("ltp_osc.Oscilloscope", self._osc).stop()
 
     @wrap_libtiepie_exception
     @_require_dev_handle(TiePieDeviceType.OSCILLOSCOPE)
@@ -483,10 +472,7 @@ class TiePieOscilloscope(SingleCommDevice):
 
         :return: if a TiePie measurement is running (ready for trigger)
         """
-        # make mypy happy w/ assert; `is None` check is already done in the
-        # `_require_dev_handle` method decorator
-        assert self._osc is not None
-        _is_running = self._osc.is_running
+        _is_running = cast("ltp_osc.Oscilloscope", self._osc).is_running
         logger.debug(f"TiePie measurement is running: {_is_running}")
         return _is_running
 
@@ -499,10 +485,7 @@ class TiePieOscilloscope(SingleCommDevice):
 
         :return: if a trigger event occurred
         """
-        # make mypy happy w/ assert; `is None` check is already done in the
-        # `_require_dev_handle` method decorator
-        assert self._osc is not None
-        _is_triggered = self._osc.is_triggered
+        _is_triggered = cast("ltp_osc.Oscilloscope", self._osc).is_triggered
         logger.debug(f"TiePie has triggered: {_is_triggered}")
         return _is_triggered
 
@@ -516,10 +499,9 @@ class TiePieOscilloscope(SingleCommDevice):
         :raises TiePieError: when device is not started or status of underlying device
             gives an error
         """
-        # make mypy happy w/ assert; `is None` check is already done in the
-        # `_require_dev_handle` method decorator
-        assert self._osc is not None
-        _is_measurement_data_ready = self._osc.is_data_ready
+        _is_measurement_data_ready = cast(
+            "ltp_osc.Oscilloscope", self._osc
+        ).is_data_ready
         logger.debug(f"TiePie has measurement data ready: {_is_measurement_data_ready}")
         return _is_measurement_data_ready
 
@@ -533,10 +515,7 @@ class TiePieOscilloscope(SingleCommDevice):
         :raises TiePieError: when device is not started or status of underlying device
             gives an error
         """
-        # make mypy happy w/ assert; `is None` check is already done in the
-        # `_require_dev_handle` method decorator
-        assert self._osc is not None
-        self._osc.force_trigger()
+        cast("ltp_osc.Oscilloscope", self._osc).force_trigger()
         logger.info("A force trigger was sent to TiePie")
 
     @wrap_libtiepie_exception
@@ -549,13 +528,9 @@ class TiePieOscilloscope(SingleCommDevice):
             filtered
         :return None:
         """
-        # make mypy happy w/ assert; `is None` check is already done in the
-        # `_require_dev_handle` method decorator
-        assert self._osc is not None
-        # make mypy happy: config_osc could be None, which has no attributes
         if self.config_osc is None:
             logger.warning("Oscilloscope is not configured")
-            return None
+            return
 
         record_length_actual = len(data_array[:, 0])
         if record_length_actual < self.config_osc.record_length:
@@ -564,13 +539,14 @@ class TiePieOscilloscope(SingleCommDevice):
                 "before all pre trigger samples could be recorded. "
                 "(pre_sample_ratio was too high)"
             )
-
-        pre_sample_count = self._osc.valid_pre_sample_count
+            pre_sample_count = cast(
+                "ltp_osc.Oscilloscope", self._osc
+            ).valid_pre_sample_count
         record_length_predicted = (
             int(self.config_osc.record_length * (1 - self.config_osc.pre_sample_ratio))
             + pre_sample_count
         )
-        if not record_length_actual == record_length_predicted:
+        if record_length_actual != record_length_predicted:
             logger.warning(
                 f"The actual record length ({record_length_actual} Sa) "
                 "is shorter than the "
@@ -580,8 +556,8 @@ class TiePieOscilloscope(SingleCommDevice):
     @wrap_libtiepie_exception
     @_require_dev_handle(TiePieDeviceType.OSCILLOSCOPE)
     def collect_measurement_data(
-        self, timeout: Optional[Number] = 0
-    ) -> Optional[npt.NDArray]:
+        self, timeout: Number | None = 0
+    ) -> npt.NDArray | None:
         """
         Try to collect the data from TiePie; return `None` if data is not ready.
 
@@ -593,15 +569,12 @@ class TiePieOscilloscope(SingleCommDevice):
             2D-`numpy.ndarray` with float sample data; or None if there is no data
             available.
         """
-        # make mypy happy w/ assert; `is None` check is already done in the
-        # `_require_dev_handle` method decorator
-        assert self._osc is not None
         # make mypy happy: config_osc could be None, which has no attributes
         if self.config_osc is None:
             logger.warning("Oscilloscope is not configured")
             return None
 
-        if timeout is not None and not isinstance(timeout, (float, int)):
+        if timeout is not None and not isinstance(timeout, float | int):
             msg = (
                 "timeout must be non-negative number, "
                 f"but '{timeout}' of type {type(timeout)} was given"
@@ -624,13 +597,15 @@ class TiePieOscilloscope(SingleCommDevice):
             return None
 
         # Collect raw data from tiepie
-        data = self._osc.get_data()
+        data = cast("ltp_osc.Oscilloscope", self._osc).get_data()
         # filter-out disabled channels entries
         data_array: npt.NDArray = np.array(list(filter(None, data))).T
 
         self._check_record_length(data_array)
 
-        pre_sample_count = self._osc.valid_pre_sample_count
+        pre_sample_count = cast(
+            "ltp_osc.Oscilloscope", self._osc
+        ).valid_pre_sample_count
         record_length_actual = len(data_array[:, 0])
         time_vector = np.arange(
             -pre_sample_count, record_length_actual - pre_sample_count
@@ -639,16 +614,16 @@ class TiePieOscilloscope(SingleCommDevice):
 
         return np.column_stack([time_vector, data_array])
 
-    @property  # type: ignore
+    @property
     @_require_dev_handle(TiePieDeviceType.OSCILLOSCOPE)
     @wrap_libtiepie_exception
-    def n_channels(self):
+    def n_channels(self) -> int:
         """
         Number of channels in the oscilloscope.
 
         :return: Number of channels.
         """
-        return len(self._osc.channels)
+        return len(self._osc.channels)  # type: ignore[union-attr]
 
     @property
     def channels_enabled(self) -> Generator[int, None, None]:
