@@ -1,8 +1,7 @@
 #  Copyright (c) ETH Zurich, SIS ID and HVL D-ITET
 #
-"""
+""" """
 
-"""
 import logging
 
 from aenum import Enum
@@ -24,14 +23,14 @@ class PublicPropertiesReprMixin:
         :return: attribute name and value tuples
         """
         for name in dir(self):
-            if not (name.startswith("_") or name.startswith("clean")):
+            if not name.startswith(("_", "clean")):
                 try:
-                    if isinstance(getattr(self, name), (int, float, str, Enum)):
+                    if isinstance(getattr(self, name), int | float | str | Enum):
                         yield name, getattr(self, name)
                 except NotImplementedError:
                     yield name, "*NotImplementedError*"
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         attrs = ", ".join(
             [f"{name}={value!r}" for name, value in self._public_properties_gen()]
         )
