@@ -4,7 +4,7 @@
 Mock OscilloscopeChannelTrigger
 """
 
-import libtiepie.const as const
+from libtiepie import const
 from libtiepie.oscilloscopechanneltrigger import (
     OscilloscopeChannelTrigger as LtpOscilloscopeChannelTrigger,
 )
@@ -14,7 +14,7 @@ from .oscilloscopechanneltriggerlevels import OscilloscopeChannelTriggerLevels
 
 
 class OscilloscopeChannelTrigger(LtpOscilloscopeChannelTrigger):
-    def __init__(self):
+    def __init__(self) -> None:
         self._enabled = False
         self._hystereses = OscilloscopeChannelTriggerHystereses()
         self._levels = OscilloscopeChannelTriggerLevels()
