@@ -10,16 +10,16 @@ from libtiepie.oscilloscopechanneltriggerhystereses import (
 
 
 class OscilloscopeChannelTriggerHystereses(LtpOscilloscopeChannelTriggerHystereses):
-    def __init__(self):
+    def __init__(self) -> None:
         self.items = [1, 2, 3]
 
-    def __getitem__(self, index):
+    def __getitem__(self, index) -> float:
         return self.items[index]
 
-    def __setitem__(self, index, value):
+    def __setitem__(self, index, value) -> None:
         self.items[index] = value
 
-    def __len__(self):
+    def __len__(self) -> int:
         return self.count
 
     def _get_count(self):
