@@ -8,7 +8,7 @@ Mock Server
 class Server:
     """"""
 
-    def __init__(self, handle):
+    def __init__(self, handle) -> None:
         self._url = handle
         self._name = f"Mocked Server Name of {handle}"
 
