@@ -21,12 +21,12 @@ def testconfig():
     )
 
 
-def test_modbus_tcp_conifg():
+def test_modbus_tcp_conifg() -> None:
     with pytest.raises(ValueError):
         ModbusTcpCommunicationConfig(host="127..1", unit=0)
 
 
-def test_modbus_tcp_connect(testconfig):
+def test_modbus_tcp_connect(testconfig) -> None:
     mbtcp = ModbusTcpCommunication(testconfig)
 
     assert mbtcp is not None
