@@ -8,10 +8,6 @@ import logging
 import time
 
 import pytest
-from masked_comm.serial import (
-    CryLasLaserLoopSerialCommunication,
-    LoopSerialCommunication,
-)
 
 from hvl_ccb.comm.serial import SerialCommunicationIOError
 from hvl_ccb.dev.crylas import (
@@ -24,6 +20,10 @@ from hvl_ccb.dev.crylas import (
     CryLasLaserSerialCommunication,
     CryLasLaserSerialCommunicationConfig,
 )
+from masked_comm.serial import (
+    CryLasLaserLoopSerialCommunication,
+    LoopSerialCommunication,
+)
 
 logging.basicConfig(level=logging.ERROR)
 
@@ -63,7 +63,7 @@ def started_laser(laser_com_config, laser_config):
         yield com, las
 
 
-def test_laser_com(laser_com_config):
+def test_laser_com(laser_com_config) -> None:
     com = CryLasLaserLoopSerialCommunication(laser_com_config)
     # test error when com closed
     assert not com.is_open
@@ -97,7 +97,7 @@ def test_laser_com(laser_com_config):
     com.close()
 
 
-def test_laser_instantiation(laser_com_config, laser_config):
+def test_laser_instantiation(laser_com_config, laser_config) -> None:
     las = CryLasLaser(laser_com_config)
     assert las is not None
 
@@ -140,7 +140,7 @@ def test_laser_instantiation(laser_com_config, laser_config):
         CryLasLaser(laser_com_config, wrong_config)
 
 
-def test_laser_start(laser_com_config, laser_config):
+def test_laser_start(laser_com_config, laser_config) -> None:
     com = CryLasLaserLoopSerialCommunication(laser_com_config)
     las = CryLasLaser(com, laser_config)
     com.open()
@@ -176,7 +176,7 @@ def test_laser_start(laser_com_config, laser_config):
         las.start()
 
 
-def test_laser_wait_until_ready(laser_com_config, laser_config):
+def test_laser_wait_until_ready(laser_com_config, laser_config) -> None:
     # test case: system not immediately ready, execution blocked
     com = CryLasLaserLoopSerialCommunication(laser_com_config)
 
@@ -229,7 +229,7 @@ def test_laser_wait_until_ready(laser_com_config, laser_config):
     las.stop()
 
 
-def test_status_polling_end(laser_com_config, laser_config):
+def test_status_polling_end(laser_com_config, laser_config) -> None:
     # test case: system not immediately ready, execution blocked
     com = CryLasLaserLoopSerialCommunication(laser_com_config)
 
@@ -272,7 +272,7 @@ def test_status_polling_end(laser_com_config, laser_config):
     assert las.laser_status == las.LaserStatus.READY_INACTIVE
 
 
-def test_laser_stop(started_laser):
+def test_laser_stop(started_laser) -> None:
     com, las = started_laser
     com.put_text(las.AnswersStatus.INACTIVE.value)
     com.put_text(las.AnswersShutter.CLOSED.value)
@@ -287,7 +287,7 @@ def test_laser_stop(started_laser):
     assert las.shutter_status == las.ShutterStatus.CLOSED
 
 
-def test_laser_on(started_laser, laser_config):
+def test_laser_on(started_laser, laser_config) -> None:
     com, las = started_laser
     # normal case
     com.put_text(las.AnswersStatus.READY.value)
@@ -358,7 +358,7 @@ def test_laser_on(started_laser, laser_config):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_off(started_laser):
+def test_laser_off(started_laser) -> None:
     com, las = started_laser
     # normal case
     las.laser_status = las.LaserStatus.READY_ACTIVE
@@ -380,7 +380,7 @@ def test_laser_off(started_laser):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_open_shutter(started_laser):
+def test_laser_open_shutter(started_laser) -> None:
     com, las = started_laser
     # normal case
     com.put_text(las.AnswersShutter.OPENED.value)
@@ -396,7 +396,7 @@ def test_laser_open_shutter(started_laser):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_close_shutter(started_laser):
+def test_laser_close_shutter(started_laser) -> None:
     com, las = started_laser
     # normal case
     com.put_text(las.AnswersShutter.CLOSED.value)
@@ -412,7 +412,7 @@ def test_laser_close_shutter(started_laser):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_set_init_shutter_status(laser_com_config, laser_config):
+def test_laser_set_init_shutter_status(laser_com_config, laser_config) -> None:
     # test with init CLOSED
     com = CryLasLaserLoopSerialCommunication(laser_com_config)
     las = CryLasLaser(com, laser_config)
@@ -450,7 +450,7 @@ def test_laser_set_init_shutter_status(laser_com_config, laser_config):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_update_laser_status(started_laser):
+def test_laser_update_laser_status(started_laser) -> None:
     com, las = started_laser
     assert las.laser_status == las.LaserStatus.READY_INACTIVE
     # no answer error
@@ -493,7 +493,7 @@ def test_laser_update_laser_status(started_laser):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_update_shutter_status(started_laser):
+def test_laser_update_shutter_status(started_laser) -> None:
     com, las = started_laser
     com.put_text(las.AnswersShutter.CLOSED.value)
     las.update_shutter_status()
@@ -509,7 +509,7 @@ def test_laser_update_shutter_status(started_laser):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_update_repetition_rate(started_laser):
+def test_laser_update_repetition_rate(started_laser) -> None:
     com, las = started_laser
     com.put_text("Impuls=enabled 10Hz")
     las.update_repetition_rate()
@@ -528,7 +528,7 @@ def test_laser_update_repetition_rate(started_laser):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_update_target_pulse_energy(started_laser):
+def test_laser_update_target_pulse_energy(started_laser) -> None:
     com, las = started_laser
     com.put_text("PD-Sollwert=46000")
     las.update_target_pulse_energy()
@@ -541,7 +541,7 @@ def test_laser_update_target_pulse_energy(started_laser):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_get_pulse_energy_and_rate(started_laser):
+def test_laser_get_pulse_energy_and_rate(started_laser) -> None:
     com, las = started_laser
     # test that the command works
     com.put_text(
@@ -559,7 +559,7 @@ def test_laser_get_pulse_energy_and_rate(started_laser):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_set_repetition_rate(started_laser):
+def test_laser_set_repetition_rate(started_laser) -> None:
     com, las = started_laser
     # check param type int
     com.put_text("Impuls=enabled 10Hz")
@@ -586,7 +586,7 @@ def test_laser_set_repetition_rate(started_laser):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_set_pulse_energy(started_laser):
+def test_laser_set_pulse_energy(started_laser) -> None:
     com, las = started_laser
     # case successful
     val = 100
@@ -613,7 +613,7 @@ def test_laser_set_pulse_energy(started_laser):
     com.put_text(las.AnswersShutter.CLOSED.value)
 
 
-def test_laser_com_error(laser_com_config, laser_config):
+def test_laser_com_error(laser_com_config, laser_config) -> None:
     wrong_config = dict(laser_com_config)
     wrong_config["port"] = "NOT A PORT"
     las = CryLasLaser(wrong_config, laser_config)
@@ -655,7 +655,7 @@ def test_laser_com_error(laser_com_config, laser_config):
         las.set_pulse_energy(200)
 
 
-def test_auto_laser_on(laser_com_config, laser_config):
+def test_auto_laser_on(laser_com_config, laser_config) -> None:
     com = CryLasLaserLoopSerialCommunication(laser_com_config)
 
     config_where_auto_laser_is_on = dict(laser_config)
@@ -725,7 +725,7 @@ def started_attenuator(attenuator_com_config, attenuator_config):
         yield serial_port, att
 
 
-def test_attenuator_instantiation(attenuator_com_config, attenuator_config):
+def test_attenuator_instantiation(attenuator_com_config, attenuator_config) -> None:
     att = CryLasAttenuator(attenuator_com_config)
     assert att is not None
 
@@ -743,14 +743,14 @@ def test_attenuator_instantiation(attenuator_com_config, attenuator_config):
         CryLasAttenuator(attenuator_com_config, wrong_config)
 
 
-def test_attenuator_start(started_attenuator):
+def test_attenuator_start(started_attenuator) -> None:
     com, att = started_attenuator
     com.put_bytes(bytes([0, 0]))
     att.start()
     assert com.get_written()
 
 
-def test_attenuator_set_attenuation(started_attenuator):
+def test_attenuator_set_attenuation(started_attenuator) -> None:
     com, att = started_attenuator
     com.put_bytes(bytes([0, 0]))
     att.set_attenuation(50)
@@ -762,7 +762,7 @@ def test_attenuator_set_attenuation(started_attenuator):
         att.set_attenuation(-1)
 
 
-def test_attenuator_com_error(attenuator_com_config, attenuator_config):
+def test_attenuator_com_error(attenuator_com_config, attenuator_config) -> None:
     wrong_config = dict(attenuator_com_config)
     wrong_config["port"] = "NOT A PORT"
     att = CryLasAttenuator(wrong_config, attenuator_config)
@@ -776,14 +776,14 @@ def test_attenuator_com_error(attenuator_com_config, attenuator_config):
         att.set_attenuation(50)
 
 
-def test_attenuator_set_init_attenuation(started_attenuator):
+def test_attenuator_set_init_attenuation(started_attenuator) -> None:
     com, att = started_attenuator
     com.put_bytes(bytes([0, 0]))
     att.set_init_attenuation()
     assert att.attenuation == att.config.init_attenuation
 
 
-def test_attenuator_set_transmission(started_attenuator):
+def test_attenuator_set_transmission(started_attenuator) -> None:
     com, att = started_attenuator
     com.put_bytes(bytes([0, 0]))
     att.set_transmission(50)
