@@ -15,12 +15,12 @@ demo_opcua_server.set_var(constants.Power.voltage_target, 0)
 """
 
 import logging
+import sys
 from concurrent.futures import ThreadPoolExecutor
 from itertools import product
 from time import sleep
 
 import pytest
-from masked_comm.opc import DemoServer
 from pytest_mock import MockerFixture
 
 from hvl_ccb.comm.opc import OpcUaCommunicationIOError, OpcUaCommunicationTimeoutError
@@ -39,6 +39,7 @@ from hvl_ccb.dev.cube import (
 from hvl_ccb.dev.cube.errors import SwitchOperationError
 from hvl_ccb.dev.cube.support import _SupportPort
 from hvl_ccb.dev.cube.switches import _Switch
+from masked_comm.opc import DemoServer
 
 
 @pytest.fixture(scope="module")
@@ -101,8 +102,8 @@ def demo_opcua_server(dev_config):
 @pytest.fixture(scope="module")
 def opened_basecube_com(
     com_config,
-    dev_config,
-    demo_opcua_server: DemoServer,
+    dev_config,  # noqa: ARG001
+    demo_opcua_server: DemoServer,  # noqa: ARG001
 ):
     opc_comm = BaseCubeOpcUaCommunication(com_config)
     opc_comm.open()
@@ -127,7 +128,7 @@ def test_basecube_subscription_handler_datachange_safetystatus(
     dev_config: dict,
     demo_opcua_server: DemoServer,
     caplog,  # pytest._logging.LogCaptureFixture
-):
+) -> None:
     ns_index = dev_config["namespace_index"]
 
     caplog.set_level(logging.INFO)
@@ -145,20 +146,13 @@ def test_basecube_subscription_handler_datachange_safetystatus(
     )
     sleep(0.05)
 
-    # FIXME: does not work in gitlab CI
-    # check presence of log messages in a correct order
-    # assert [
-    #     f"Safety: {str(constants.SafetyStatus.Initializing)}",
-    #     f"Safety: {str(constants.SafetyStatus.GreenNotReady)}",
-    # ] == _get_logged_messages(caplog, "hvl_ccb.dev.basecube.base", logging.INFO)
-
 
 def test_basecube_subscription_handler_datachange_earthingstickstatus(
     opened_basecube_com,
     dev_config: dict,
     demo_opcua_server: DemoServer,
     caplog,  # pytest._logging.LogCaptureFixture
-):
+) -> None:
     ns_index = dev_config["namespace_index"]
 
     caplog.set_level(logging.INFO)
@@ -181,19 +175,6 @@ def test_basecube_subscription_handler_datachange_earthingstickstatus(
         )
     sleep(0.05)
 
-    # FIXME: does not work in gitlab CI
-    # check presence of log messages in a correct order
-    # assert (
-    #     [
-    #         f"Earthing {ess.number}: {str(constants.SwitchStatus.inactive)}"
-    #         for ess in ess_tuple
-    #     ]
-    #     + [
-    #         f"Earthing {ess.number}: {str(constants.SwitchStatus.closed)}"
-    #         for ess in ess_tuple
-    #     ]
-    # ) == _get_logged_messages(caplog, "hvl_ccb.dev.basecube.base", logging.INFO)
-
 
 @pytest.fixture(scope="module")
 def cube(com_config, dev_config, demo_opcua_server: DemoServer):
@@ -208,7 +189,7 @@ def cube(com_config, dev_config, demo_opcua_server: DemoServer):
     cube.stop()
 
 
-def test_dev_config(dev_config):
+def test_dev_config(dev_config) -> None:
     # currently there are no non-default config values
     config = BaseCubeConfiguration(**dev_config)
     for key, value in dev_config.items():
@@ -226,7 +207,7 @@ def test_dev_config(dev_config):
         {"timeout_status_change": -1},
     ],
 )
-def test_invalid_config_dict_value_error(dev_config, wrong_config_dict):
+def test_invalid_config_dict_value_error(dev_config, wrong_config_dict) -> None:
     invalid_config = dict(dev_config)
     invalid_config.update(wrong_config_dict)
     with pytest.raises(ValueError):
@@ -239,14 +220,14 @@ def test_invalid_config_dict_value_error(dev_config, wrong_config_dict):
         {"noise_level_measurement_channel_1": "100"},
     ],
 )
-def test_invalid_config_dict_type_error(dev_config, wrong_config_dict):
+def test_invalid_config_dict_type_error(dev_config, wrong_config_dict) -> None:
     invalid_config = dict(dev_config)
     invalid_config.update(wrong_config_dict)
     with pytest.raises(TypeError):
         BaseCubeConfiguration(**invalid_config)
 
 
-def test_set_remote_control(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_set_remote_control(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     cube._set_remote_control(False)
     assert demo_opcua_server.get_var(constants._OpcControl.ACTIVE) is False
     cube._set_remote_control(True)
@@ -276,7 +257,7 @@ def test_status_poller(
     dev_config,
     demo_opcua_server: DemoServer,
     mocker: MockerFixture,
-):
+) -> None:
     cube = BaseCube(com_config, dev_config)
     poller = cube._status_poller
     assert poller is not None
@@ -314,7 +295,7 @@ def test_status_poller_timeout_error(
     dev_config,
     demo_opcua_server: DemoServer,
     mocker: MockerFixture,
-):
+) -> None:
     cube = BaseCube(com_config, dev_config)
     demo_opcua_server.set_var(constants._OpcControl.TIME, [0, 0, 0, 0, 0, 0, 0])
     cube.start()
@@ -328,7 +309,7 @@ def test_status_poller_timeout_error(
     # Use bound method (otherwise live unpatch does not work):
     send_request_orig = cube.com._client.uaclient.protocol.send_request
 
-    async def send_request(self, request, *args, **kwargs):
+    async def send_request(_self, request, *args, **kwargs):
         if hasattr(request, "Parameters") and hasattr(
             request.Parameters, "NodesToWrite"
         ):
@@ -337,9 +318,13 @@ def test_status_poller_timeout_error(
                 node_to_write.NodeId.Identifier == constants._OpcControl.ACTIVE
                 and node_to_write.Value.Value.Value is False
             ):
-                from concurrent.futures import TimeoutError
+                if sys.version_info < (3, 11):
+                    from concurrent.futures import TimeoutError as FuturesTimeoutError
+                else:
+                    FuturesTimeoutError = TimeoutError  # noqa: N806
 
-                raise TimeoutError("mock timeout error")
+                msg = "mock timeout error"
+                raise FuturesTimeoutError(msg)
         # method already bound - ignore `self`
         return await send_request_orig(request, *args, **kwargs)
 
@@ -369,16 +354,16 @@ def test_status_poller_timeout_error(
 
     with pytest.raises(OpcUaCommunicationIOError) as excinfo:
         cube.stop()
-        assert excinfo.type is not OpcUaCommunicationTimeoutError
+    assert excinfo.type is not OpcUaCommunicationTimeoutError
     assert not cube._status_poller.is_polling()
 
 
-def test_support_input(cube: BaseCube):
+def test_support_input(cube: BaseCube) -> None:
     assert cube.support_1.input_1 is False
     assert cube.support_1.input_2 is False
 
 
-def test_support_output(cube: BaseCube):
+def test_support_output(cube: BaseCube) -> None:
     cube.support_1.output_1 = False
     assert cube.support_1.output_1 is False
     cube.support_1.output_1 = True
@@ -399,7 +384,7 @@ def test_support_output(cube: BaseCube):
         cube.support_1.output_1 = "on"
 
 
-def test_t13_socket(cube: BaseCube):
+def test_t13_socket(cube: BaseCube) -> None:
     assert cube.t13_socket_1 is False
     cube.t13_socket_1 = True
     assert cube.t13_socket_1 is True
@@ -413,7 +398,7 @@ def test_t13_socket(cube: BaseCube):
         cube.t13_socket_1 = "on"
 
 
-def test_cee16_socket(cube: BaseCube):
+def test_cee16_socket(cube: BaseCube) -> None:
     cube.cee16_socket = False
     assert cube.cee16_socket is False
     cube.cee16_socket = True
@@ -429,7 +414,7 @@ def test_cee16_socket(cube: BaseCube):
         cube.cee16_socket = "on"
 
 
-def test_get_status(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_get_status(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     demo_opcua_server.set_var(constants._Safety.STATUS, 1)
     assert cube.status == constants.SafetyStatus.GREEN_NOT_READY
 
@@ -446,7 +431,7 @@ def _switch_safety_status(
     demo_opcua_server.set_var(constants._Safety.STATUS, int(safety_status))
 
 
-def test_ready(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_ready(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     demo_opcua_server.set_var(
         constants._SafetyStatusTransition.SWITCH_TO_READY.command, False
     )
@@ -486,7 +471,7 @@ def test_ready(cube: BaseCube, demo_opcua_server: DemoServer):
     assert cube.ready is None
 
 
-def test_operate(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_operate(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     demo_opcua_server.set_var(
         constants._SafetyStatusTransition.SWITCH_TO_OPERATE.command, False
     )
@@ -526,7 +511,7 @@ def test_operate(cube: BaseCube, demo_opcua_server: DemoServer):
     assert cube.operate is None
 
 
-def test_switch_safety_status(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_switch_safety_status(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     demo_opcua_server.set_var(
         constants._Safety.STATUS, int(constants.SafetyStatus.GREEN_NOT_READY)
     )
@@ -541,20 +526,23 @@ def test_switch_safety_status(cube: BaseCube, demo_opcua_server: DemoServer):
     demo_opcua_server.set_var(
         constants._Safety.STATUS, int(constants.SafetyStatus.GREEN_READY)
     )
+    demo_opcua_server.set_var(
+        constants._SafetyStatusTransition.SWITCH_TO_READY.command, False
+    )
     with pytest.raises(CubeStatusChangeError):
         cube._switch_safety_status(
             constants._SafetyStatusTransition.SWITCH_TO_READY, True
         )
 
 
-def test_get_measurement_ratio(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_get_measurement_ratio(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     demo_opcua_server.set_var(
         constants._MeasurementChannel("", 1, 400)._CMD_RATIO, 123.4
     )
     assert cube.measurement_ch_1.ratio == 123.4
 
 
-def test_get_measurement_voltage(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_get_measurement_voltage(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     demo_opcua_server.set_var(
         constants._MeasurementChannel("", 1, 400)._CMD_SCALE, True
     )
@@ -571,7 +559,10 @@ def test_get_measurement_voltage(cube: BaseCube, demo_opcua_server: DemoServer):
     assert cube.measurement_ch_1.voltage == 110
 
 
-def test_switch_without_plc_fields(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_switch_without_plc_fields(
+    cube: BaseCube,
+    demo_opcua_server: DemoServer,  # noqa: ARG001
+) -> None:
     class Switch(_Switch):
         """Inheritance of _Switch as this cannot be instanced"""
 
@@ -587,14 +578,16 @@ def test_switch_without_plc_fields(cube: BaseCube, demo_opcua_server: DemoServer
         assert switch.operate
 
 
-def test_get_earthing_stick_status(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_get_earthing_stick_status(
+    cube: BaseCube, demo_opcua_server: DemoServer
+) -> None:
     demo_opcua_server.set_var(earthing_stick._EarthingStick("", 1)._CMD_STATUS, 1)
     assert cube.earthing_stick_1.status == earthing_stick.SwitchStatus(1)
 
 
 def test_get_earthing_stick_operating_status(
     cube: BaseCube, demo_opcua_server: DemoServer
-):
+) -> None:
     demo_opcua_server.set_var(
         earthing_stick._EarthingStick("", 1)._CMD_OPERATING_STATUS,
         earthing_stick.SwitchOperatingStatus.AUTO,
@@ -605,7 +598,9 @@ def test_get_earthing_stick_operating_status(
     )
 
 
-def test_get_earthing_stick_manual(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_get_earthing_stick_manual(
+    cube: BaseCube, demo_opcua_server: DemoServer
+) -> None:
     demo_opcua_server.set_var(
         earthing_stick._EarthingStick("", 1)._CMD_MANUAL,
         bool(earthing_stick.SwitchOperation.CLOSE),
@@ -613,7 +608,7 @@ def test_get_earthing_stick_manual(cube: BaseCube, demo_opcua_server: DemoServer
     assert cube.earthing_stick_1.operate is earthing_stick.SwitchOperation.CLOSE
 
 
-def test_operate_earthing_stick(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_operate_earthing_stick(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     demo_opcua_server.set_var(
         earthing_stick._EarthingStick("", 1)._CMD_OPERATING_STATUS,
         earthing_stick.SwitchOperatingStatus.MANUAL,
@@ -664,7 +659,7 @@ def test_operate_earthing_stick(cube: BaseCube, demo_opcua_server: DemoServer):
 def test_operate_earthing_stick_error(
     cube: BaseCube,
     demo_opcua_server: DemoServer,
-):
+) -> None:
     demo_opcua_server.set_var(
         earthing_stick._EarthingStick("", 1)._CMD_OPERATING_STATUS,
         earthing_stick.SwitchOperatingStatus.AUTO,
@@ -673,48 +668,52 @@ def test_operate_earthing_stick_error(
         cube.earthing_stick_1.operate = earthing_stick.SwitchOperation.CLOSE
 
 
-def test_quit_error(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_quit_error(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     demo_opcua_server.set_var(constants._Errors.QUIT, False)
     cube.quit_error()
     assert demo_opcua_server.get_var(constants._Errors.QUIT) is False
 
 
-def test_get_door_status(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_get_door_status(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     demo_opcua_server.set_var(constants._Door(1, "")._CMD, 2)
     assert cube.door_1_status == constants.DoorStatus(2)
 
 
-def test_base_descriptor(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_base_descriptor(cube: BaseCube, demo_opcua_server: DemoServer) -> None:  # noqa: ARG001
     with pytest.raises(AttributeError):
         cube.door_1_status = True
 
 
-def test_get_earthing_rod_status(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_get_earthing_rod_status(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     demo_opcua_server.set_var(constants._EarthingRod(1, "")._CMD, 0)
     assert cube.earthing_rod_1_status == constants.EarthingRodStatus(0)
     demo_opcua_server.set_var(constants._EarthingRod(1, "")._CMD, 1)
     assert cube.earthing_rod_1_status == constants.EarthingRodStatus(1)
 
 
-def test_get_breakdown_detection_active(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_get_breakdown_detection_active(
+    cube: BaseCube, demo_opcua_server: DemoServer
+) -> None:
     demo_opcua_server.set_var(constants._BreakdownDetection.ACTIVATED, True)
     assert cube.breakdown_detection_active is True
 
 
 def test_get_breakdown_detection_triggered(
     cube: BaseCube, demo_opcua_server: DemoServer
-):
+) -> None:
     demo_opcua_server.set_var(constants._BreakdownDetection.TRIGGERED, True)
     assert cube.breakdown_detection_triggered is True
 
 
-def test_breakdown_detection_reset(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_breakdown_detection_reset(
+    cube: BaseCube, demo_opcua_server: DemoServer
+) -> None:
     demo_opcua_server.set_var(constants._BreakdownDetection.RESET, False)
     cube.breakdown_detection_reset()
     assert demo_opcua_server.get_var(constants._BreakdownDetection.RESET) is False
 
 
-def test_set_status_board(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_set_status_board(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     n_max = len(constants.MessageBoard)
 
     with pytest.raises(ValueError):
@@ -743,7 +742,7 @@ def test_set_status_board(cube: BaseCube, demo_opcua_server: DemoServer):
         assert demo_opcua_server.get_var(constants.MessageBoard.line(i + 1)) == str(i)
 
 
-def test_set_message_board(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_set_message_board(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     n_max = len(constants.MessageBoard)
 
     with pytest.raises(ValueError):
@@ -772,14 +771,14 @@ def test_set_message_board(cube: BaseCube, demo_opcua_server: DemoServer):
     assert last_msg.endswith(msgs[0])
 
 
-def test_active_alarms(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_active_alarms(cube: BaseCube, demo_opcua_server: DemoServer) -> None:  # noqa: ARG001
     cube._com.config.sub_handler.alarm_status = alarms._AlarmsOverview()
     cube._com.config.sub_handler.alarm_status.alarm_50 = alarms._AlarmStatus.ACTIVE
     assert cube.active_alarms(False) == [50]
     assert cube.active_alarms(True) == ["OPC Connection active"]
 
 
-def test_stop(cube: BaseCube, demo_opcua_server: DemoServer):
+def test_stop(cube: BaseCube, demo_opcua_server: DemoServer) -> None:
     demo_opcua_server.set_var(
         constants._Safety.STATUS, int(constants.SafetyStatus.RED_READY)
     )
