@@ -7,7 +7,6 @@ Tests for the hvl_ccb.dev.heinzinger sub-package.
 import logging
 
 import pytest
-from masked_comm.serial import HeinzingerLoopSerialCommunication
 
 from hvl_ccb.comm.serial import SerialCommunicationIOError
 from hvl_ccb.dev.heinzinger.base import HeinzingerSerialCommunicationConfig
@@ -17,6 +16,7 @@ from hvl_ccb.dev.heinzinger.constants import (
     RecordingsEnum,
 )
 from hvl_ccb.dev.heinzinger.device import Heinzinger, HeinzingerConfig
+from masked_comm.serial import HeinzingerLoopSerialCommunication
 
 logging.basicConfig(level=logging.ERROR)
 
@@ -46,7 +46,7 @@ def dev_config():
 
 
 class ConcreteHeinzinger(Heinzinger):
-    def start(self):
+    def start(self) -> None:
         super().start()
 
 
@@ -81,7 +81,7 @@ def start_heinzinger_device(com_config, dev_config):
     return _start_heinzinger_device
 
 
-def test_heinzinger_number_of_recordings(started_heinzinger_device):
+def test_heinzinger_number_of_recordings(started_heinzinger_device) -> None:
     com, heinzinger = started_heinzinger_device
     # set a new value
     heinzinger.number_of_recordings = 4
@@ -98,13 +98,13 @@ def test_heinzinger_number_of_recordings(started_heinzinger_device):
     com.put_text("0.0")  # when device stop, voltage is set to 0
 
 
-def test_com_config(com_config):
+def test_com_config(com_config) -> None:
     config = HeinzingerSerialCommunicationConfig(**com_config)
     for key, value in com_config.items():
         assert getattr(config, key) == value
 
 
-def test_dev_config(dev_config):
+def test_dev_config(dev_config) -> None:
     # currently there are no non-default config values
     HeinzingerConfig()
 
@@ -122,14 +122,14 @@ def test_dev_config(dev_config):
         {"number_of_decimals": 6, "wait_sec_stop_commands": -1},
     ],
 )
-def test_invalid_config_dict(dev_config, wrong_config_dict):
+def test_invalid_config_dict(dev_config, wrong_config_dict) -> None:
     invalid_config = dict(dev_config)
     invalid_config.update(wrong_config_dict)
     with pytest.raises(ValueError):
         HeinzingerConfig(**invalid_config)
 
 
-def test_heinzinger_instantiation(com_config, dev_config):
+def test_heinzinger_instantiation(com_config, dev_config) -> None:
     heinzinger = ConcreteHeinzinger(com_config)
     assert heinzinger is not None
 
@@ -137,7 +137,7 @@ def test_heinzinger_instantiation(com_config, dev_config):
     assert heinzinger is not None
 
 
-def test_heinzinger_stop(started_heinzinger_device):
+def test_heinzinger_stop(started_heinzinger_device) -> None:
     com, heinzinger = started_heinzinger_device
     com.put_text("0.0")
     heinzinger.stop()
@@ -150,14 +150,14 @@ def test_heinzinger_stop(started_heinzinger_device):
     assert not com.get_written()
 
 
-def test_heinzinger_reset_interface(started_heinzinger_device):
+def test_heinzinger_reset_interface(started_heinzinger_device) -> None:
     com, heinzinger = started_heinzinger_device
     heinzinger.reset_interface()
     assert com.get_written() == "*RST"
     com.put_text("0.0")  # when device stop, voltage is set to 0
 
 
-def test_heinzinger_output_status_property(started_heinzinger_device):
+def test_heinzinger_output_status_property(started_heinzinger_device) -> None:
     com, heinzinger = started_heinzinger_device
     assert heinzinger.output is None
     heinzinger.output = True
@@ -167,7 +167,7 @@ def test_heinzinger_output_status_property(started_heinzinger_device):
     com.put_text("0.0")  # when device stop, voltage is set to 0
 
 
-def test_heinzinger_com_error(com_config, dev_config):
+def test_heinzinger_com_error(com_config, dev_config) -> None:
     wrong_config = dict(com_config)
     wrong_config["port"] = "NOT A PORT"
     heinzinger = ConcreteHeinzinger(wrong_config, dev_config)
@@ -191,20 +191,20 @@ def test_heinzinger_com_error(com_config, dev_config):
     with pytest.raises(SerialCommunicationIOError):
         heinzinger.get_serial_number()
     with pytest.raises(SerialCommunicationIOError):
-        heinzinger.number_of_recordings
+        assert heinzinger.number_of_recordings
     with pytest.raises(SerialCommunicationIOError):
         heinzinger.number_of_recordings = RecordingsEnum.EIGHT
     with pytest.raises(SerialCommunicationIOError):
         heinzinger.voltage = 1
     with pytest.raises(SerialCommunicationIOError):
-        heinzinger.voltage
+        assert heinzinger.voltage
     with pytest.raises(SerialCommunicationIOError):
         heinzinger.current = 1
     with pytest.raises(SerialCommunicationIOError):
-        heinzinger.current
+        assert heinzinger.current
 
 
-def test_heinzinger_deprecation_warning(started_heinzinger_device):
+def test_heinzinger_deprecation_warning(started_heinzinger_device) -> None:
     com, heinzinger = started_heinzinger_device
     with pytest.raises(DeprecationWarning):
         heinzinger.output_on()
@@ -232,7 +232,7 @@ devices_data = [
 
 
 @pytest.mark.parametrize("device_data", devices_data)
-def test_heinzinger_start(start_heinzinger_device, com_config, device_data):
+def test_heinzinger_start(start_heinzinger_device, device_data) -> None:
     started_heinzinger = start_heinzinger_device(device_data[0])
     com, heinzinger = next(started_heinzinger)
 
@@ -249,14 +249,14 @@ def test_heinzinger_start(start_heinzinger_device, com_config, device_data):
     )
 
 
-def test_heinzinger_not_recognized(start_heinzinger_device):
+def test_heinzinger_not_recognized(start_heinzinger_device) -> None:
     with pytest.raises(HeinzingerDeviceNotRecognizedError):
         next(start_heinzinger_device("ABC 600-3000pos 375214277"))
 
 
-def test_heinzinger_set_max_voltage(start_heinzinger_device):
+def test_heinzinger_set_max_voltage(start_heinzinger_device) -> None:
     started_heinzinger = start_heinzinger_device("PNC 600-3000pos 375214277")
-    com, heinzinger = next(started_heinzinger)
+    _com, heinzinger = next(started_heinzinger)
 
     # set max_voltage to half the current value
     next_value = heinzinger.max_voltage / 2
@@ -273,9 +273,9 @@ def test_heinzinger_set_max_voltage(start_heinzinger_device):
         heinzinger.max_voltage = -1
 
 
-def test_pnc_set_max_current(start_heinzinger_device):
+def test_pnc_set_max_current(start_heinzinger_device) -> None:
     started_heinzinger = start_heinzinger_device("PNC 600-3000pos 375214277")
-    com, heinzinger = next(started_heinzinger)
+    _com, heinzinger = next(started_heinzinger)
 
     # set max_voltage to half the current value
     next_value = heinzinger.max_current / 2
@@ -292,9 +292,9 @@ def test_pnc_set_max_current(start_heinzinger_device):
         heinzinger.max_current = -1
 
 
-def test_pnc_set_negative(start_heinzinger_device):
+def test_pnc_set_negative(start_heinzinger_device) -> None:
     started_heinzinger = start_heinzinger_device("PNC 600-3000pos 375214277")
-    com, heinzinger = next(started_heinzinger)
+    _com, heinzinger = next(started_heinzinger)
 
     # assigning negative value
     with pytest.raises(ValueError):
@@ -315,7 +315,7 @@ devices_u = [
 
 
 @pytest.mark.parametrize("device_data", devices_u)
-def test_heinzinger_set_voltage(start_heinzinger_device, device_data):
+def test_heinzinger_set_voltage(start_heinzinger_device, device_data) -> None:
     started_heinzinger = start_heinzinger_device(device_data[0])
     com, heinzinger = next(started_heinzinger)
 
@@ -331,11 +331,11 @@ def test_heinzinger_set_voltage(start_heinzinger_device, device_data):
     assert heinzinger.set_voltage == device_data[1]
 
     # test if an error is raised when trying to set a too high voltage
+    com.put_text(str(device_data[4]))
     with pytest.raises(ValueError):
-        com.put_text(str(device_data[4]))
         heinzinger.voltage = device_data[4]
+    com.put_text("2.0")
     with pytest.raises(HeinzingerSetValueError):
-        com.put_text("2.0")
         heinzinger.voltage = device_data[1]
 
 
@@ -351,7 +351,7 @@ devices_i = [
 
 
 @pytest.mark.parametrize("device_data", devices_i)
-def test_heinzinger_set_current(start_heinzinger_device, device_data):
+def test_heinzinger_set_current(start_heinzinger_device, device_data) -> None:
     started_heinzinger = start_heinzinger_device(device_data[0])
     com, heinzinger = next(started_heinzinger)
 
@@ -367,9 +367,9 @@ def test_heinzinger_set_current(start_heinzinger_device, device_data):
     assert heinzinger.set_current == device_data[1]
 
     # test if an error is raised when trying to set a too high current
+    com.put_text(str(device_data[4]))
     with pytest.raises(ValueError):
-        com.put_text(str(device_data[4]))
         heinzinger.current = device_data[4]
+    com.put_text("2.0")
     with pytest.raises(HeinzingerSetValueError):
-        com.put_text("2.0")
         heinzinger.current = device_data[1]
