@@ -7,7 +7,6 @@ Tests for the newport sub-package.
 import logging
 
 import pytest
-from masked_comm.serial import NewportLoopSerialCommunication
 
 from hvl_ccb.comm.serial import SerialCommunicationIOError
 from hvl_ccb.dev.newport import (
@@ -21,8 +20,10 @@ from hvl_ccb.dev.newport import (
     NewportSMC100PPSerialCommunicationConfig,
     NewportUncertainPositionError,
 )
+from masked_comm.serial import NewportLoopSerialCommunication
 
 logging.basicConfig(level=logging.ERROR)
+logger = logging.getLogger(__name__)
 
 
 @pytest.fixture(scope="module")
@@ -86,7 +87,7 @@ def started_newport(com_config, dev_config):
         cmd = NewportConfigCommands(param).name
         val = motor_config[param]  # matching config values
         com.put_text(f"1{cmd}{val}")
-        logging.debug(f"putting to com: 1{cmd}{val}")
+        logger.debug(f"putting to com: 1{cmd}{val}")
     com.put_text("1PW0")
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
 
@@ -111,7 +112,7 @@ def started_newport(com_config, dev_config):
             com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
 
 
-def test_com_read_text(com_config):
+def test_com_read_text(com_config) -> None:
     com = NewportLoopSerialCommunication(com_config)
     com.open()
     # check that no error is raised
@@ -126,7 +127,7 @@ def test_com_read_text(com_config):
         com.read_text()
 
 
-def test_com_check_for_error(com_config):
+def test_com_check_for_error(com_config) -> None:
     com = NewportLoopSerialCommunication(com_config)
     com.open()
     # check that no error is raised
@@ -144,7 +145,7 @@ def test_com_check_for_error(com_config):
         com.check_for_error(1)
 
 
-def test_com_send_command(com_config):
+def test_com_send_command(com_config) -> None:
     com = NewportLoopSerialCommunication(com_config)
     com.open()
 
@@ -173,7 +174,7 @@ def test_com_send_command(com_config):
         com.send_command(1, "command")
 
 
-def test_com_query(com_config):
+def test_com_query(com_config) -> None:
     com = NewportLoopSerialCommunication(com_config)
     com.open()
     # check that the correct answer is returned
@@ -202,7 +203,7 @@ def test_com_query(com_config):
         com.query(1, "query")
 
 
-def test_com_query_multiple(com_config):
+def test_com_query_multiple(com_config) -> None:
     com = NewportLoopSerialCommunication(com_config)
     com.open()
 
@@ -211,21 +212,21 @@ def test_com_query_multiple(com_config):
     cmd = "ZT"
     prefixes = ["one", "two", "three"]
     values = [1, 2, 3]
-    for p, v in zip(prefixes, values):
+    for p, v in zip(prefixes, values, strict=False):
         com.put_text(f"{p}{v}")
     com.put_text(f"{add}TE{com.ControllerErrors.NO_ERROR.value}")
     assert com.query_multiple(add, cmd, prefixes) == [str(v) for v in values]
 
     # wrong prefix
     wrong_prefixes = ["one", "two", "four"]
-    for p, v in zip(prefixes, values):
+    for p, v in zip(prefixes, values, strict=False):
         com.put_text(f"{p}{v}")
     com.put_text(f"{add}TE{com.ControllerErrors.NO_ERROR.value}")
     with pytest.raises(NewportSerialCommunicationError):
         com.query_multiple(add, cmd, wrong_prefixes)
 
     # check that NewportControllerError is raised
-    for p, v in zip(prefixes, values):
+    for p, v in zip(prefixes, values, strict=False):
         com.put_text(f"{p}{v}")
     com.put_text(f"{add}TE{com.ControllerErrors.CMD_NOT_ALLOWED.value}")
     with pytest.raises(NewportControllerError):
@@ -237,7 +238,7 @@ def test_com_query_multiple(com_config):
         com.query_multiple(add, cmd, prefixes)
 
 
-def test_dev_config(dev_config):
+def test_dev_config(dev_config) -> None:
     # currently there are no non-default config values
     NewportSMC100PPConfig()
 
@@ -282,14 +283,14 @@ def test_dev_config(dev_config):
         {"stage_configuration": -1},
     ],
 )
-def test_invalid_config_dict(dev_config, wrong_config_dict):
+def test_invalid_config_dict(dev_config, wrong_config_dict) -> None:
     invalid_config = dict(dev_config)
     invalid_config.update(wrong_config_dict)
     with pytest.raises(ValueError):
         NewportSMC100PPConfig(**invalid_config)
 
 
-def test_newport_instantiation(com_config, dev_config):
+def test_newport_instantiation(com_config, dev_config) -> None:
     mot = NewportSMC100PP(com_config)
     assert mot is not None
 
@@ -297,7 +298,7 @@ def test_newport_instantiation(com_config, dev_config):
     assert mot is not None
 
 
-def test_newport_com_errors(com_config, dev_config):
+def test_newport_com_errors(com_config, dev_config) -> None:
     wrong_com_config = dict(com_config)
     wrong_com_config["port"] = "NOT A PORT"
     mot = NewportSMC100PP(wrong_com_config, dev_config)
@@ -350,7 +351,7 @@ def test_newport_com_errors(com_config, dev_config):
         mot.set_negative_software_limit(-1)
 
 
-def test_start_and_initialize(com_config, dev_config):
+def test_start_and_initialize(com_config, dev_config) -> None:
     com = NewportLoopSerialCommunication(com_config)
     com.open()
 
@@ -370,7 +371,7 @@ def test_start_and_initialize(com_config, dev_config):
         cmd = NewportConfigCommands(param).name
         val = config[param]  # matching config values
         com.put_text(f"1{cmd}{val}")
-        logging.debug(f"putting to com: 1{cmd}{val}")
+        logger.debug(f"putting to com: 1{cmd}{val}")
     com.put_text("1PW0")
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
 
@@ -385,7 +386,7 @@ def test_start_and_initialize(com_config, dev_config):
     assert mot.state == state_message.state
 
 
-def test_start_and_configure(com_config, dev_config):
+def test_start_and_configure(com_config, dev_config) -> None:
     com = NewportLoopSerialCommunication(com_config)
     com.open()
 
@@ -405,7 +406,7 @@ def test_start_and_configure(com_config, dev_config):
         cmd = NewportConfigCommands(param).name
         val = config[param] + 1  # changed config values
         com.put_text(f"1{cmd}{val}")
-        logging.debug(f"putting to com: 1{cmd}{val}")
+        logger.debug(f"putting to com: 1{cmd}{val}")
     com.put_text("1PW0")
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
 
@@ -433,13 +434,13 @@ def test_start_and_configure(com_config, dev_config):
     assert mot.state == state_message.state
 
 
-def test_stop(started_newport):
+def test_stop(started_newport) -> None:
     com, mot = started_newport
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
     mot.stop()
 
 
-def test_get_state(started_newport):
+def test_get_state(started_newport) -> None:
     com, mot = started_newport
 
     state = NewportSMC100PP.StateMessages.MOVING.value
@@ -482,7 +483,7 @@ def test_get_state(started_newport):
     assert mot.state == mot.States.DISABLE
 
 
-def test_get_motor_configuration(started_newport):
+def test_get_motor_configuration(started_newport) -> None:
     com, mot = started_newport
 
     com.put_text("1PW1")
@@ -491,7 +492,7 @@ def test_get_motor_configuration(started_newport):
         cmd = NewportConfigCommands(param).name
         val = mot.config.motor_config[param]
         com.put_text(f"1{cmd}{val}")
-        logging.debug(f"putting to com: 1{cmd}{val}")
+        logger.debug(f"putting to com: 1{cmd}{val}")
     com.put_text("1PW0")
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
     assert mot.get_motor_configuration() == mot.config.motor_config
@@ -499,7 +500,7 @@ def test_get_motor_configuration(started_newport):
     assert com.get_written() == "1TE"
 
 
-def test_go_to_configuration(started_newport):
+def test_go_to_configuration(started_newport) -> None:
     com, mot = started_newport
     # artificially put the controller in NOT REFERENCED state
     state = NewportSMC100PP.StateMessages.NO_REF_FROM_RESET.value
@@ -516,7 +517,7 @@ def test_go_to_configuration(started_newport):
     assert mot.state == mot.States.CONFIG
 
 
-def test_set_motor_configuration(started_newport):
+def test_set_motor_configuration(started_newport) -> None:
     com, mot = started_newport
 
     config = mot.config.motor_config
@@ -537,7 +538,7 @@ def test_set_motor_configuration(started_newport):
         mot.set_motor_configuration()
 
 
-def test_exit_configuration(started_newport):
+def test_exit_configuration(started_newport) -> None:
     com, mot = started_newport
     # start the test
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
@@ -547,7 +548,7 @@ def test_exit_configuration(started_newport):
     assert mot.state == mot.States.NO_REF
 
 
-def test_initialize(started_newport):
+def test_initialize(started_newport) -> None:
     com, mot = started_newport
     # start the test
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
@@ -557,7 +558,7 @@ def test_initialize(started_newport):
     assert mot.state == mot.States.READY
 
 
-def test_wait_until_motor_initialized(started_newport):
+def test_wait_until_motor_initialized(started_newport) -> None:
     com, mot = started_newport
     # normal case
     state = NewportSMC100PP.StateMessages.HOMING_FROM_RS232.value
@@ -578,7 +579,7 @@ def test_wait_until_motor_initialized(started_newport):
         mot.wait_until_motor_initialized()
 
 
-def test_reset(started_newport):
+def test_reset(started_newport) -> None:
     com, mot = started_newport
     # start the test
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
@@ -589,7 +590,7 @@ def test_reset(started_newport):
     assert mot.state == mot.States.NO_REF
 
 
-def test_get_position(started_newport):
+def test_get_position(started_newport) -> None:
     com, mot = started_newport
     # start the test
     pos = 12
@@ -610,7 +611,7 @@ def test_get_position(started_newport):
         mot.get_position()
 
 
-def test_move_to_absolute_position(started_newport):
+def test_move_to_absolute_position(started_newport) -> None:
     com, mot = started_newport
     # start the test
     pos = 3
@@ -622,11 +623,11 @@ def test_move_to_absolute_position(started_newport):
     mot.move_to_absolute_position(pos)
     assert com.get_written() == "1TP"
     assert com.get_written() == "1TE"
-    assert com.get_written() == f"1PA{pos-mot.config.user_position_offset}"
+    assert com.get_written() == f"1PA{pos - mot.config.user_position_offset}"
     assert com.get_written() == "1TE"
 
 
-def test_go_home(started_newport):
+def test_go_home(started_newport) -> None:
     com, mot = started_newport
     # start the test
     pos = 3
@@ -642,7 +643,7 @@ def test_go_home(started_newport):
     assert com.get_written() == "1TE"
 
 
-def test_move_to_relative_position(started_newport):
+def test_move_to_relative_position(started_newport) -> None:
     com, mot = started_newport
     # start the test
     pos = -3
@@ -654,7 +655,7 @@ def test_move_to_relative_position(started_newport):
     assert com.get_written() == "1TE"
 
 
-def test_get_move_duration(started_newport):
+def test_get_move_duration(started_newport) -> None:
     com, mot = started_newport
     dist = -3
     duration = 5.2
@@ -666,7 +667,7 @@ def test_get_move_duration(started_newport):
     assert com.get_written() == "1TE"
 
 
-def test_stop_motion(started_newport):
+def test_stop_motion(started_newport) -> None:
     com, mot = started_newport
     # test if stop_motion_works
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
@@ -679,7 +680,7 @@ def test_stop_motion(started_newport):
     assert com.get_written() == "1TE"
 
 
-def test_get_acceleration(started_newport):
+def test_get_acceleration(started_newport) -> None:
     com, mot = started_newport
     acc = 5
     com.put_text(f"1AC{acc}")
@@ -689,7 +690,7 @@ def test_get_acceleration(started_newport):
     assert com.get_written() == "1TE"
 
 
-def test_set_acceleration(started_newport):
+def test_set_acceleration(started_newport) -> None:
     com, mot = started_newport
     acc = 5
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
@@ -698,7 +699,7 @@ def test_set_acceleration(started_newport):
     assert com.get_written() == "1TE"
 
 
-def test_get_controller_information(started_newport):
+def test_get_controller_information(started_newport) -> None:
     com, mot = started_newport
     com.put_text("1VE SMC100PP")
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
@@ -707,7 +708,7 @@ def test_get_controller_information(started_newport):
     assert com.get_written() == "1TE"
 
 
-def test_get_positive_software_limit(started_newport):
+def test_get_positive_software_limit(started_newport) -> None:
     com, mot = started_newport
     lim = 5
     com.put_text(f"1SR{lim}")
@@ -717,7 +718,7 @@ def test_get_positive_software_limit(started_newport):
     assert com.get_written() == "1TE"
 
 
-def test_get_negative_software_limit(started_newport):
+def test_get_negative_software_limit(started_newport) -> None:
     com, mot = started_newport
     lim = -5
     com.put_text(f"1SL{lim}")
@@ -727,7 +728,7 @@ def test_get_negative_software_limit(started_newport):
     assert com.get_written() == "1TE"
 
 
-def test_set_positive_software_limit(started_newport):
+def test_set_positive_software_limit(started_newport) -> None:
     com, mot = started_newport
     lim = 5
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
@@ -736,7 +737,7 @@ def test_set_positive_software_limit(started_newport):
     assert com.get_written() == "1TE"
 
 
-def test_set_negative_software_limit(started_newport):
+def test_set_negative_software_limit(started_newport) -> None:
     com, mot = started_newport
     lim = -5
     com.put_text(f"1TE{com.ControllerErrors.NO_ERROR.value}")
