@@ -7,7 +7,6 @@ Tests for the .dev.pfeiffer_tpg sub-package.
 import logging
 
 import pytest
-from masked_comm.serial import PfeifferTPGLoopSerialCommunication
 
 from hvl_ccb.comm.serial import SerialCommunicationIOError
 from hvl_ccb.dev.pfeiffer_tpg import (
@@ -16,6 +15,7 @@ from hvl_ccb.dev.pfeiffer_tpg import (
     PfeifferTPGError,
     PfeifferTPGSerialCommunicationConfig,
 )
+from masked_comm.serial import PfeifferTPGLoopSerialCommunication
 
 logging.basicConfig(level=logging.ERROR)
 
@@ -44,10 +44,7 @@ def started_pfeiffer_tpg(com_config, dev_config):
     com.open()
     com.put_text(chr(6))
     com.put_text(
-        ",".join([
-            PfeifferTPG.SensorTypes.CMR.name,
-            PfeifferTPG.SensorTypes.noSENSOR.name,
-        ])
+        f"{PfeifferTPG.SensorTypes.CMR.name},{PfeifferTPG.SensorTypes.noSENSOR.name}"
     )
     with PfeifferTPG(com, dev_config) as pg:
         while com.get_written() is not None:
@@ -55,7 +52,7 @@ def started_pfeiffer_tpg(com_config, dev_config):
         yield com, pg
 
 
-def test_pfeiffer_tpg_instantiation(com_config, dev_config):
+def test_pfeiffer_tpg_instantiation(com_config, dev_config) -> None:
     pg = PfeifferTPG(com_config, dev_config)
     assert pg is not None
     assert pg.unit == "mbar"
@@ -71,7 +68,7 @@ def test_pfeiffer_tpg_instantiation(com_config, dev_config):
         PfeifferTPG(com_config, config_dict)
 
 
-def test_com_send_command(com_config):
+def test_com_send_command(com_config) -> None:
     com = PfeifferTPGLoopSerialCommunication(com_config)
     com.open()
     com.put_text(chr(6))
@@ -83,7 +80,7 @@ def test_com_send_command(com_config):
     com.close()
 
 
-def test_com_query(com_config):
+def test_com_query(com_config) -> None:
     com = PfeifferTPGLoopSerialCommunication(com_config)
     com.open()
     com.put_text(chr(6))
@@ -101,18 +98,18 @@ def test_com_query(com_config):
     com.close()
 
 
-def test_pfeiffer_tpg_start(started_pfeiffer_tpg):
+def test_pfeiffer_tpg_start(started_pfeiffer_tpg) -> None:
     com, pg = started_pfeiffer_tpg
     # starting again should work
     com.put_text(chr(6))
-    com.put_text(",".join(["Unknown", PfeifferTPG.SensorTypes.CMR.name]))
+    com.put_text(f"Unknown,{PfeifferTPG.SensorTypes.CMR.name}")
     pg.start()
     assert pg.number_of_sensors == 2
     assert pg.sensors[0] == "Unknown"
     assert pg.sensors[1] == "APR/CMR Linear Gauge"
 
 
-def test_pfeiffer_com_error(com_config, dev_config):
+def test_pfeiffer_com_error(com_config, dev_config) -> None:
     wrong_config = dict(com_config)
     wrong_config["port"] = "NOT A PORT"
     tpg = PfeifferTPG(wrong_config, dev_config)
@@ -141,16 +138,12 @@ def test_pfeiffer_com_error(com_config, dev_config):
         tpg.get_full_scale_mbar()
 
 
-def test_identify_sensors(started_pfeiffer_tpg):
+def test_identify_sensors(started_pfeiffer_tpg) -> None:
     com, pg = started_pfeiffer_tpg
     # example with 3 sensors
     com.put_text(chr(6))
     com.put_text(
-        ",".join([
-            PfeifferTPG.SensorTypes.PKR.name,
-            PfeifferTPG.SensorTypes.CMR.name,
-            PfeifferTPG.SensorTypes.IKR.name,
-        ])
+        f"{PfeifferTPG.SensorTypes.PKR.name},{PfeifferTPG.SensorTypes.CMR.name},{PfeifferTPG.SensorTypes.IKR.name}"
     )
     pg.identify_sensors()
     assert com.get_written() == "TID"
@@ -165,7 +158,7 @@ def test_identify_sensors(started_pfeiffer_tpg):
         pg.identify_sensors()
 
 
-def test_measure(started_pfeiffer_tpg):
+def test_measure(started_pfeiffer_tpg) -> None:
     com, pg = started_pfeiffer_tpg
     # normal case
     com.put_text(chr(6))
@@ -208,7 +201,7 @@ def test_measure(started_pfeiffer_tpg):
         pg.measure(1)
 
 
-def test_measure_all(started_pfeiffer_tpg):
+def test_measure_all(started_pfeiffer_tpg) -> None:
     com, pg = started_pfeiffer_tpg
     # normal case
     com.put_text(chr(6))
@@ -227,7 +220,7 @@ def test_measure_all(started_pfeiffer_tpg):
         pg.measure_all()
 
 
-def test_set_full_scale_unitless(started_pfeiffer_tpg):
+def test_set_full_scale_unitless(started_pfeiffer_tpg) -> None:
     com, pg = started_pfeiffer_tpg
     com.put_text(chr(6))
     pg.set_full_scale_unitless([1, 2])
@@ -246,7 +239,7 @@ def test_set_full_scale_unitless(started_pfeiffer_tpg):
         pg.set_full_scale_unitless([12, 24, 32])
 
 
-def test_get_full_scale_unitless(started_pfeiffer_tpg):
+def test_get_full_scale_unitless(started_pfeiffer_tpg) -> None:
     com, pg = started_pfeiffer_tpg
     com.put_text(chr(6))
     com.put_text("2,0")
@@ -263,7 +256,7 @@ def test_get_full_scale_unitless(started_pfeiffer_tpg):
         pg.get_full_scale_unitless()
 
 
-def test_set_full_scale_mbar(started_pfeiffer_tpg):
+def test_set_full_scale_mbar(started_pfeiffer_tpg) -> None:
     com, pg = started_pfeiffer_tpg
     com.put_text(chr(6))
     pg.set_full_scale_mbar([100, 1])
@@ -283,7 +276,7 @@ def test_set_full_scale_mbar(started_pfeiffer_tpg):
         pg.set_full_scale_mbar([12, 24, 32])
 
 
-def test_get_full_scale_mbar(started_pfeiffer_tpg):
+def test_get_full_scale_mbar(started_pfeiffer_tpg) -> None:
     com, pg = started_pfeiffer_tpg
     com.put_text(chr(6))
     com.put_text("2,0")
