@@ -24,7 +24,7 @@ def dev_config():
     }
 
 
-def test_instantiation(com_config, dev_config):
+def test_instantiation(dev_config) -> None:
     dev = Pt104({}, dev_config)
     assert dev is not None
 
@@ -38,13 +38,13 @@ def test_instantiation(com_config, dev_config):
         },
     ],
 )
-def test_dev_config_invalid(dev_config, wrong_config_dict):
+def test_dev_config_invalid(dev_config, wrong_config_dict) -> None:
     invalid_config = dict(dev_config)
     invalid_config.update(wrong_config_dict)
     with pytest.raises(AttributeError):
         Pt104DeviceConfig(**invalid_config)
 
 
-def test_ct_requires_host():
+def test_ct_requires_host() -> None:
     assert Pt104CommunicationType.ETHERNET.requires_host
     assert not Pt104CommunicationType.USB.requires_host
