@@ -3,28 +3,28 @@
 """
 Tests for .dev sub-package technix
 """
+
 import logging
 from time import sleep
 
 import pytest
-from masked_comm import LocalTechnixServer
-from masked_comm.serial import TechnixLoopSerialCommunication
-from masked_comm.utils import get_free_tcp_port
 
 from hvl_ccb.dev.technix import (
     Technix,
     TechnixError,
     TechnixSerialCommunication,
     TechnixSerialCommunicationConfig,
-    TechnixTelnetCommunication,
+    TechnixTcpCommunication,
 )
 from hvl_ccb.dev.technix.base import _GetRegisters, _Status
+from masked_comm.serial import TechnixLoopSerialCommunication
+from mocked_comm.tcp import LocalTechnixServer, get_free_tcp_port
 
 logging.basicConfig(level=logging.DEBUG)
 
 
-@pytest.fixture(scope="function")
-def com_telnet():
+@pytest.fixture
+def com_tcp():
     host = "127.0.0.1"
     return {
         "host": host,
@@ -50,11 +50,11 @@ def com_serial():
 
 
 @pytest.fixture(scope="module")
-def dev_config_telnet():
+def dev_config_tcp():
     return {
         "max_voltage": 10000,
         "max_current": 1.5,
-        "communication_channel": TechnixTelnetCommunication,
+        "communication_channel": TechnixTcpCommunication,
         "post_stop_pause_sec": 0.01,
         "register_pulse_time": 0.01,
         "polling_interval_sec": 1,
@@ -72,25 +72,24 @@ def dev_config_serial():
     }
 
 
-@pytest.fixture()
-def start_technix_telnet(com_telnet, dev_config_telnet):
-    ts = LocalTechnixServer(port=com_telnet["port"], timeout=com_telnet["timeout"])
-    with ts:
-        tex = Technix(com_telnet, dev_config_telnet)
+@pytest.fixture
+def start_technix_tcp(com_tcp, dev_config_tcp):
+    ts = LocalTechnixServer(port=com_tcp["port"], timeout=com_tcp["timeout"])
+    tex = Technix(com_tcp, dev_config_tcp)
+    with ts, tex:
         ts._starting.join()
-        with tex:
-            tex.query_status()
-            yield ts, tex
+        tex.query_status()
+        yield ts, tex
 
 
-def test_mockup(start_technix_telnet):
-    ts, tex = start_technix_telnet
+def test_mockup(start_technix_tcp) -> None:
+    _ts, tex = start_technix_tcp
 
     tex.query_status()
 
 
-def test_devices(start_technix_telnet):
-    ts, tex = start_technix_telnet
+def test_devices(start_technix_tcp) -> None:
+    ts, tex = start_technix_tcp
     assert ts is not None
     assert tex.__class__ is Technix
 
@@ -102,8 +101,8 @@ def test_devices(start_technix_telnet):
     assert not tex.is_started
 
 
-def test_no_properties(start_technix_telnet):
-    ts, tex = start_technix_telnet
+def test_no_properties(start_technix_tcp) -> None:
+    _ts, tex = start_technix_tcp
     """Device is not fully started, statuses are None"""
     tex.stop()
 
@@ -117,27 +116,29 @@ def test_no_properties(start_technix_telnet):
     assert tex.current == 0
 
 
-def test_wrong_command(start_technix_telnet):
-    ts, tex = start_technix_telnet
+def test_wrong_command(start_technix_tcp) -> None:
+    ts, tex = start_technix_tcp
 
     listen_and_repeat_backup = ts.listen_and_repeat
 
     with pytest.raises(TechnixError):
         tex.com.query("no_register")
+
+    ts.custom_answer = "P7,1"
+    ts.listen_and_repeat = ()
     with pytest.raises(TechnixError):
-        ts.custom_answer = "P7,1"
-        ts.listen_and_repeat = ()
         tex.inhibit = True
+
+    ts.custom_answer = "P7,1"
+    ts.listen_and_repeat = ()
     with pytest.raises(TechnixError):
-        ts.custom_answer = "P7,1"
-        ts.listen_and_repeat = ()
         tex._get_register(_GetRegisters.VOLTAGE)
 
     ts.listen_and_repeat = listen_and_repeat_backup
 
 
-def test_watchdog(start_technix_telnet):
-    ts, tex = start_technix_telnet
+def test_watchdog(start_technix_tcp) -> None:
+    ts, tex = start_technix_tcp
     assert tex.is_started
 
     ts.status = 0b010
@@ -146,12 +147,12 @@ def test_watchdog(start_technix_telnet):
     assert not tex.is_started
 
 
-def test_status(start_technix_telnet):
-    ts, tex = start_technix_telnet
+def test_status(start_technix_tcp) -> None:
+    ts, tex = start_technix_tcp
 
     # Wrong status byte
+    ts.status = 1000
     with pytest.raises(ValueError):
-        ts.status = 1000
         tex.query_status()
 
     # Correct status
@@ -169,13 +170,13 @@ def test_status(start_technix_telnet):
     assert tex.voltage_regulation is False
 
     # Status fault and closed interlock
+    ts.status = 0b010
     with pytest.raises(TechnixError):
-        ts.status = 0b010
         tex.query_status()
 
 
-def test_voltage_current(start_technix_telnet):
-    ts, tex = start_technix_telnet
+def test_voltage_current(start_technix_tcp) -> None:
+    ts, tex = start_technix_tcp
 
     tex.query_status()
 
@@ -214,8 +215,8 @@ def test_voltage_current(start_technix_telnet):
         tex.current = 1e6
 
 
-def test_voltage_current_with_status(start_technix_telnet):
-    ts, tex = start_technix_telnet
+def test_voltage_current_with_status(start_technix_tcp) -> None:
+    ts, tex = start_technix_tcp
 
     from hvl_ccb.configuration import _force_value
 
@@ -229,8 +230,8 @@ def test_voltage_current_with_status(start_technix_telnet):
     assert tex.current == 1
 
 
-def test_hv_remote_inhibit(start_technix_telnet):
-    ts, tex = start_technix_telnet
+def test_hv_remote_inhibit(start_technix_tcp) -> None:
+    _ts, tex = start_technix_tcp
 
     tex.output = True
     tex.output = False
@@ -268,7 +269,7 @@ def start_serial_devices(com_serial, dev_config_serial):
     return com, tex
 
 
-def test_serial(com_serial, dev_config_serial):
+def test_serial(com_serial, dev_config_serial) -> None:
     com, tex = start_serial_devices(com_serial, dev_config_serial)
 
     com.put_text("P6,1")
