@@ -10,12 +10,6 @@ import libtiepie as ltp
 import numpy as np
 import pytest
 from libtiepie.exceptions import InvalidDeviceSerialNumberError, LibTiePieException
-from mock_libtiepie.const import (  # MOCK_I2CHOST_SERIAL_NUMBER,
-    MOCK_DEVICE_SERIAL_NUMBER,
-    MOCK_GENERATOR_SERIAL_NUMBER,
-    MOCK_OSCILLOSCOPE_SERIAL_NUMBER,
-    MOCK_OSCILLOSCOPE_SERIAL_NUMBER_2,
-)
 from pytest_mock import MockerFixture
 
 from hvl_ccb.dev.tiepie import (  # TiePieI2CHostMixin,
@@ -38,13 +32,16 @@ from hvl_ccb.dev.tiepie import (  # TiePieI2CHostMixin,
 )
 from hvl_ccb.dev.tiepie.base import _verify_via_libtiepie
 
-"""
-Mocking libtiepie
-"""
-# from mock_libtiepie import i2chost as _i2chost  # noqa: E402
-from mock_libtiepie import generator as _generator  # noqa: E402
-from mock_libtiepie import oscilloscope as _oscilloscope  # noqa: E402
-from mock_libtiepie.devicelist import device_list as _device_list  # noqa: E402
+# from mock_libtiepie import i2chost as _i2chost
+from mock_libtiepie import generator as _generator
+from mock_libtiepie import oscilloscope as _oscilloscope
+from mock_libtiepie.const import (  # MOCK_I2CHOST_SERIAL_NUMBER,
+    MOCK_DEVICE_SERIAL_NUMBER,
+    MOCK_GENERATOR_SERIAL_NUMBER,
+    MOCK_OSCILLOSCOPE_SERIAL_NUMBER,
+    MOCK_OSCILLOSCOPE_SERIAL_NUMBER_2,
+)
+from mock_libtiepie.devicelist import device_list as _device_list
 
 libtiepie = sys.modules["libtiepie"]
 
@@ -70,7 +67,7 @@ def dev_config():
     }
 
 
-def test_instantiation(com_config, dev_config):
+def test_instantiation(com_config, dev_config) -> None:
     dev_hs6 = TiePieHS6(com_config, dev_config)
     assert dev_hs6 is not None
     dev_hs5 = TiePieHS5(com_config, dev_config)
@@ -79,7 +76,9 @@ def test_instantiation(com_config, dev_config):
     assert dev_ws5 is not None
 
 
-def test_wrap_libtiepie_exception(com_config, dev_config, mocker: MockerFixture):
+def test_wrap_libtiepie_exception(
+    com_config, dev_config, mocker: MockerFixture
+) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
     def raise_libtiepie_exception():
@@ -103,13 +102,15 @@ def test_wrap_libtiepie_exception(com_config, dev_config, mocker: MockerFixture)
         dev_osc.start()
 
 
-def test_list_devices(com_config, dev_config):
+def test_list_devices(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
     list_devices = dev_osc.list_devices()
     assert list_devices is not None
 
 
-def test_list_devices_none_available(com_config, dev_config, mocker: MockerFixture):
+def test_list_devices_none_available(
+    com_config, dev_config, mocker: MockerFixture
+) -> None:
     # simulate absence of devices
     mock_devices = mocker.patch.object(libtiepie.device_list, "mock_devices")
     mock_devices.return_value = False
@@ -119,7 +120,7 @@ def test_list_devices_none_available(com_config, dev_config, mocker: MockerFixtu
     assert not list_devices
 
 
-def test_get_device_by_serial_number():
+def test_get_device_by_serial_number() -> None:
     dev_osc = get_device_by_serial_number(
         MOCK_OSCILLOSCOPE_SERIAL_NUMBER,
         TiePieDeviceType.OSCILLOSCOPE,
@@ -148,14 +149,16 @@ def test_get_device_by_serial_number():
         {"is_data_ready_polling_interval_sec": 0.0},
     ],
 )
-def test_invalid_config_dict(dev_config, wrong_dev_config):
+def test_invalid_config_dict(dev_config, wrong_dev_config) -> None:
     invalid_config = dict(dev_config)
     invalid_config.update(wrong_dev_config)
     with pytest.raises(ValueError):
         TiePieDeviceConfig(**invalid_config)
 
 
-def test_get_device_by_serial_number_not_available(dev_config, mocker: MockerFixture):
+def test_get_device_by_serial_number_not_available(
+    dev_config, mocker: MockerFixture
+) -> None:
     # simulate absence of devices
     mock_devices = mocker.patch.object(libtiepie.device_list, "mock_devices")
     mock_devices.return_value = False
@@ -169,7 +172,7 @@ def test_get_device_by_serial_number_not_available(dev_config, mocker: MockerFix
         )
 
 
-def test_get_device_by_serial_number_wrong_device_type():
+def test_get_device_by_serial_number_wrong_device_type() -> None:
     with pytest.raises(TiePieError):
         get_device_by_serial_number(
             MOCK_GENERATOR_SERIAL_NUMBER,
@@ -180,7 +183,7 @@ def test_get_device_by_serial_number_wrong_device_type():
 def test_get_device_by_serial_number_invalid_device_sn(
     dev_config,
     mocker: MockerFixture,
-):
+) -> None:
     # simulate invalid device serian number error
     get_item_by_serial_number = mocker.patch.object(
         libtiepie.device_list,
@@ -197,7 +200,7 @@ def test_get_device_by_serial_number_invalid_device_sn(
         )
 
 
-def test_block_measurement_support():
+def test_block_measurement_support() -> None:
     dev_osc = TiePieOscilloscope(
         {},
         {"serial_number": MOCK_OSCILLOSCOPE_SERIAL_NUMBER_2},
@@ -207,7 +210,7 @@ def test_block_measurement_support():
         dev_osc.start()
 
 
-def test_channel_config_on_start_stop(com_config, dev_config):
+def test_channel_config_on_start_stop(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
     assert not dev_osc.config_osc_channel_dict
@@ -229,7 +232,7 @@ def test_channel_config_on_start_stop(com_config, dev_config):
     dev_osc.stop()
 
 
-def test_channels_enabled(com_config, dev_config):
+def test_channels_enabled(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
     dev_osc.start()
     for ch_config in dev_osc.config_osc_channel_dict.values():
@@ -241,17 +244,17 @@ def test_channels_enabled(com_config, dev_config):
     dev_osc.stop()
 
 
-def test_n_channels(com_config, dev_config):
+def test_n_channels(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
     dev_osc.start()
     assert dev_osc.n_channels == 3
     dev_osc.stop()
 
 
-def test_dev_osc_not_running(com_config, dev_config):
+def test_dev_osc_not_running(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
     with pytest.raises(TiePieError):
-        dev_osc.n_channels == 3
+        assert dev_osc.n_channels == 3
 
     class TiePieGeneratorOscilloscope(TiePieGeneratorMixin, TiePieOscilloscope):
         pass
@@ -269,12 +272,12 @@ def test_dev_osc_not_running(com_config, dev_config):
     #     dev_i2c._i2c_config_setup()  # ATM only priv method avail for testing
 
 
-def test_safeground_enabled(com_config, dev_config):
+def test_safeground_enabled(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
     dev_osc.start()
 
-    for ch_nr, ch_config in dev_osc.config_osc_channel_dict.items():
+    for ch_config in dev_osc.config_osc_channel_dict.values():
         assert ch_config.safeground_enabled is False
 
     for ch_nr in [1, 3]:
@@ -285,33 +288,33 @@ def test_safeground_enabled(com_config, dev_config):
     dev_osc.stop()
 
 
-def test_safeground_not_available(com_config, dev_config):
+def test_safeground_not_available(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
     dev_osc.start()
 
-    for ch_nr, ch_config in dev_osc.config_osc_channel_dict.items():
-        ch_config.channel.disable_safeground_option()
+    for ch_config in dev_osc.config_osc_channel_dict.values():
+        ch_config._channel.disable_safeground_option()
 
-    for ch_nr, ch_config in dev_osc.config_osc_channel_dict.items():
+    for ch_nr in dev_osc.config_osc_channel_dict:
         with pytest.raises(TiePieError):
             dev_osc.config_osc_channel_dict[ch_nr].safeground_enabled = True
         with pytest.raises(TiePieError):
-            dev_osc.config_osc_channel_dict[ch_nr].safeground_enabled
+            assert dev_osc.config_osc_channel_dict[ch_nr].safeground_enabled
 
     dev_osc.stop()
 
 
-def test_trigger_enabled(com_config, dev_config):
+def test_trigger_enabled(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
-    for ch_nr, ch_config in dev_osc.config_osc_channel_dict.items():
+    for ch_config in dev_osc.config_osc_channel_dict.values():
         ch_config.trigger_enabled = False
         assert ch_config.trigger_enabled is False
 
     dev_osc.start()
 
-    for ch_nr, ch_config in dev_osc.config_osc_channel_dict.items():
+    for ch_config in dev_osc.config_osc_channel_dict.values():
         assert ch_config.trigger_enabled is False
 
     for ch_nr in [1, 3]:
@@ -333,7 +336,7 @@ def test_trigger_enabled(com_config, dev_config):
     dev_osc.stop()
 
 
-def test_scope_config_set(com_config, dev_config):
+def test_scope_config_set(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
     assert dev_osc.config_osc is None
@@ -387,7 +390,7 @@ def test_scope_config_set(com_config, dev_config):
     assert dev_osc.config_osc is None
 
 
-def test_scope_config_set_invalid(com_config, dev_config):
+def test_scope_config_set_invalid(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
     dev_osc.start()
@@ -438,7 +441,7 @@ def test_scope_config_set_invalid(com_config, dev_config):
         config_osc.auto_resolution_mode = "Disabled"
 
 
-def test_channel_config_set(com_config, dev_config):
+def test_channel_config_set(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
     assert not dev_osc.config_osc_channel_dict
@@ -489,7 +492,7 @@ def test_channel_config_set(com_config, dev_config):
         assert ch2_config.probe_gain == 1
 
     # safeground enabled
-    ch2_config.channel.enable_safeground_option()
+    ch2_config._channel.enable_safeground_option()
     safeground_enabled_value = True
     ch2_config.safeground_enabled = safeground_enabled_value
     assert ch2_config.safeground_enabled == safeground_enabled_value
@@ -543,7 +546,7 @@ def test_channel_config_set(com_config, dev_config):
     assert not dev_osc.config_osc_channel_dict
 
 
-def test_channel_config_set_invalid(com_config, dev_config):
+def test_channel_config_set_invalid(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
     assert not dev_osc.config_osc_channel_dict
@@ -593,7 +596,7 @@ def test_channel_config_set_invalid(com_config, dev_config):
             ch_config.trigger_enabled = v
 
 
-def test_trigger_check(com_config, dev_config):
+def test_trigger_check(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
     dev_osc.start()
@@ -627,7 +630,7 @@ def _test_measure_data_ch(ch_nr, ch_data, rec_lngth_reduced=0):
             assert ch_data[i] == float(i)
 
 
-def test_start_and_stop_measurement(com_config, dev_config):
+def test_start_and_stop_measurement(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
     dev_osc.start()
     if not dev_osc.is_measurement_running():
@@ -664,7 +667,7 @@ def _test_measure_and_collect(dev_osc, timeout, rec_lngth_reduced=0):
     _test_measure_data(data, rec_lngth_reduced=rec_lngth_reduced)
 
 
-def test_measure_and_collect(com_config, dev_config):
+def test_measure_and_collect(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
     dev_osc.start()
@@ -685,7 +688,7 @@ def test_measure_and_collect(com_config, dev_config):
     dev_osc.stop()
 
 
-def test_measure_and_collect_fail(com_config, dev_config):
+def test_measure_and_collect_fail(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
 
     dev_osc.start()
@@ -706,7 +709,7 @@ def test_measure_and_collect_fail(com_config, dev_config):
     dev_osc.stop()
 
 
-def test_generator_config_set(com_config, dev_config):
+def test_generator_config_set(com_config, dev_config) -> None:
     dev_ws5 = TiePieWS5(com_config, dev_config)
     assert dev_ws5 is not None
 
@@ -765,7 +768,7 @@ def test_generator_config_set(com_config, dev_config):
     assert dev_ws5.config_gen is None
 
 
-def test_generator_config_set_invalid(com_config, dev_config):
+def test_generator_config_set_invalid(com_config, dev_config) -> None:
     dev_ws5 = TiePieWS5(com_config, dev_config)
     assert dev_ws5 is not None
 
@@ -811,7 +814,7 @@ def test_generator_config_set_invalid(com_config, dev_config):
     dev_ws5.stop()
 
 
-def test_generate_signal(com_config, dev_config):
+def test_generate_signal(com_config, dev_config) -> None:
     dev_ws5 = TiePieWS5(com_config, dev_config)
     assert dev_ws5 is not None
 
@@ -830,7 +833,7 @@ def test_generate_signal(com_config, dev_config):
     dev_ws5.stop()
 
 
-def test_verify_via_libtiepie():
+def test_verify_via_libtiepie() -> None:
     dev_osc = get_device_by_serial_number(
         MOCK_OSCILLOSCOPE_SERIAL_NUMBER,
         TiePieDeviceType.OSCILLOSCOPE,
@@ -840,7 +843,7 @@ def test_verify_via_libtiepie():
     assert _verify_via_libtiepie(dev_osc, "record_length", 10) == 10
 
 
-def test_config_print_values(com_config, dev_config):
+def test_config_print_values(com_config, dev_config) -> None:
     dev_osc = TiePieOscilloscope(com_config, dev_config)
     dev_osc.start()
     config_osc = dev_osc.config_osc
@@ -862,6 +865,6 @@ def test_config_print_values(com_config, dev_config):
     # assert "()" in str(config_i2c)  # no config properties yet
 
 
-def test_missing_i2c_support():
+def test_missing_i2c_support() -> None:
     with pytest.raises(DeprecationWarning):
         from hvl_ccb.dev.tiepie import i2c  # noqa: F401
