@@ -11,7 +11,7 @@ from hvl_ccb.utils.conversion import LEM4000S, LMT70A
 from hvl_ccb.utils.conversion.utils import GetAttr, SetAttr
 
 
-def test_lem4000s():
+def test_lem4000s() -> None:
     lem = LEM4000S()
     assert lem.shunt == 1.2
     lem.shunt = 2
@@ -30,7 +30,7 @@ def test_lem4000s():
     assert lem.convert(1.2) == -5250
 
 
-def test_lmt70a():
+def test_lmt70a() -> None:
     lmt = LMT70A()
     with pytest.raises(AttributeError):
         lmt.LUT = 1
@@ -40,7 +40,7 @@ def test_lmt70a():
     assert np.isnan(lmt.convert(0.3))
 
 
-def test_set_attr():
+def test_set_attr() -> None:
     class Helper:
         help_attr_1 = SetAttr(0, "help_attr_1", (0, 10), validator=LEM4000S)
         help_attr_2 = GetAttr(10, "help_attr_2")
